"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetClientScheduleRequest(object):
    """Implementation of the 'GetClientScheduleRequest' model.

    Attributes:
        client_id (str): The ID of the requested client.
        unique_client_id (int): The unique ID of the requested client.  Note: you
            need to provide the 'UniqueClientId' OR the 'ClientId'. If both are
            provided, the 'UniqueClientId' takes precedence.
        client_associated_sites_offset (int): The number of sites to skip when
            returning the site associated with a client.
        cross_regional_lookup (bool): When `true`, indicates that past and scheduled
            client visits across all sites in the region are returned.  When `false`,
            indicates that only visits at the current site are returned.
        end_date (datetime): The date past which class visits are not returned.
            Default is today’s date
        start_date (datetime): The date before which class visits are not returned.
            Default is the end date
        include_waitlist_entries (bool): When `true`, waitlist entries are included
            in the response.  When `false`, waitlist entries are removed from the
            response.  Default: **false**
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_id": "ClientId",
        "unique_client_id": "UniqueClientId",
        "client_associated_sites_offset": "ClientAssociatedSitesOffset",
        "cross_regional_lookup": "CrossRegionalLookup",
        "end_date": "EndDate",
        "start_date": "StartDate",
        "include_waitlist_entries": "IncludeWaitlistEntries",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "client_id",
        "unique_client_id",
        "client_associated_sites_offset",
        "cross_regional_lookup",
        "end_date",
        "start_date",
        "include_waitlist_entries",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        client_id=APIHelper.SKIP,
        unique_client_id=APIHelper.SKIP,
        client_associated_sites_offset=APIHelper.SKIP,
        cross_regional_lookup=APIHelper.SKIP,
        end_date=APIHelper.SKIP,
        start_date=APIHelper.SKIP,
        include_waitlist_entries=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetClientScheduleRequest instance."""
        # Initialize members of the class
        if client_id is not APIHelper.SKIP:
            self.client_id = client_id
        if unique_client_id is not APIHelper.SKIP:
            self.unique_client_id = unique_client_id
        if client_associated_sites_offset is not APIHelper.SKIP:
            self.client_associated_sites_offset = client_associated_sites_offset
        if cross_regional_lookup is not APIHelper.SKIP:
            self.cross_regional_lookup = cross_regional_lookup
        if end_date is not APIHelper.SKIP:
            self.end_date =\
                 APIHelper.apply_datetime_converter(
                end_date, APIHelper.RFC3339DateTime)\
                 if end_date else None
        if start_date is not APIHelper.SKIP:
            self.start_date =\
                 APIHelper.apply_datetime_converter(
                start_date, APIHelper.RFC3339DateTime)\
                 if start_date else None
        if include_waitlist_entries is not APIHelper.SKIP:
            self.include_waitlist_entries = include_waitlist_entries
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else APIHelper.SKIP
        unique_client_id =\
            dictionary.get("UniqueClientId")\
            if dictionary.get("UniqueClientId")\
                else APIHelper.SKIP
        client_associated_sites_offset =\
            dictionary.get("ClientAssociatedSitesOffset")\
            if dictionary.get("ClientAssociatedSitesOffset")\
                else APIHelper.SKIP
        cross_regional_lookup =\
            dictionary.get("CrossRegionalLookup")\
            if "CrossRegionalLookup" in dictionary.keys()\
                else APIHelper.SKIP
        end_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDate")).datetime\
            if dictionary.get("EndDate") else APIHelper.SKIP
        start_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDate")).datetime\
            if dictionary.get("StartDate") else APIHelper.SKIP
        include_waitlist_entries =\
            dictionary.get("IncludeWaitlistEntries")\
            if "IncludeWaitlistEntries" in dictionary.keys()\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client_id,
                   unique_client_id,
                   client_associated_sites_offset,
                   cross_regional_lookup,
                   end_date,
                   start_date,
                   include_waitlist_entries,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _unique_client_id=(
            self.unique_client_id
            if hasattr(self, "unique_client_id")
            else None
        )
        _client_associated_sites_offset=(
            self.client_associated_sites_offset
            if hasattr(self, "client_associated_sites_offset")
            else None
        )
        _cross_regional_lookup=(
            self.cross_regional_lookup
            if hasattr(self, "cross_regional_lookup")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _include_waitlist_entries=(
            self.include_waitlist_entries
            if hasattr(self, "include_waitlist_entries")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!r}, "
            f"unique_client_id={_unique_client_id!r}, "
            f"client_associated_sites_offset={_client_associated_sites_offset!r}, "
            f"cross_regional_lookup={_cross_regional_lookup!r}, "
            f"end_date={_end_date!r}, "
            f"start_date={_start_date!r}, "
            f"include_waitlist_entries={_include_waitlist_entries!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _unique_client_id=(
            self.unique_client_id
            if hasattr(self, "unique_client_id")
            else None
        )
        _client_associated_sites_offset=(
            self.client_associated_sites_offset
            if hasattr(self, "client_associated_sites_offset")
            else None
        )
        _cross_regional_lookup=(
            self.cross_regional_lookup
            if hasattr(self, "cross_regional_lookup")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _include_waitlist_entries=(
            self.include_waitlist_entries
            if hasattr(self, "include_waitlist_entries")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!s}, "
            f"unique_client_id={_unique_client_id!s}, "
            f"client_associated_sites_offset={_client_associated_sites_offset!s}, "
            f"cross_regional_lookup={_cross_regional_lookup!s}, "
            f"end_date={_end_date!s}, "
            f"start_date={_start_date!s}, "
            f"include_waitlist_entries={_include_waitlist_entries!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class CopyCreditCardRequest(object):
    """Implementation of the 'CopyCreditCardRequest' model.

    crosssite/copycreditcard

    Attributes:
        source_site_id (int): The siteId of the source clientId.
        source_client_id (str): The clientId at the source siteId.
        source_unique_client_id (int): The unique clidnetId at the source siteId.
        target_site_id (int): The siteId of the target clientId.
        target_client_id (str): The clientId at the target siteId.
        target_unique_client_id (int): The unique clidnetId at the target siteId.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "source_site_id": "SourceSiteId",
        "source_client_id": "SourceClientId",
        "source_unique_client_id": "SourceUniqueClientId",
        "target_site_id": "TargetSiteId",
        "target_client_id": "TargetClientId",
        "target_unique_client_id": "TargetUniqueClientId",
    }

    _optionals = [
        "source_site_id",
        "source_client_id",
        "source_unique_client_id",
        "target_site_id",
        "target_client_id",
        "target_unique_client_id",
    ]

    def __init__(
        self,
        source_site_id=APIHelper.SKIP,
        source_client_id=APIHelper.SKIP,
        source_unique_client_id=APIHelper.SKIP,
        target_site_id=APIHelper.SKIP,
        target_client_id=APIHelper.SKIP,
        target_unique_client_id=APIHelper.SKIP):
        """Initialize a CopyCreditCardRequest instance."""
        # Initialize members of the class
        if source_site_id is not APIHelper.SKIP:
            self.source_site_id = source_site_id
        if source_client_id is not APIHelper.SKIP:
            self.source_client_id = source_client_id
        if source_unique_client_id is not APIHelper.SKIP:
            self.source_unique_client_id = source_unique_client_id
        if target_site_id is not APIHelper.SKIP:
            self.target_site_id = target_site_id
        if target_client_id is not APIHelper.SKIP:
            self.target_client_id = target_client_id
        if target_unique_client_id is not APIHelper.SKIP:
            self.target_unique_client_id = target_unique_client_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        source_site_id =\
            dictionary.get("SourceSiteId")\
            if dictionary.get("SourceSiteId")\
                else APIHelper.SKIP
        source_client_id =\
            dictionary.get("SourceClientId")\
            if dictionary.get("SourceClientId")\
                else APIHelper.SKIP
        source_unique_client_id =\
            dictionary.get("SourceUniqueClientId")\
            if dictionary.get("SourceUniqueClientId")\
                else APIHelper.SKIP
        target_site_id =\
            dictionary.get("TargetSiteId")\
            if dictionary.get("TargetSiteId")\
                else APIHelper.SKIP
        target_client_id =\
            dictionary.get("TargetClientId")\
            if dictionary.get("TargetClientId")\
                else APIHelper.SKIP
        target_unique_client_id =\
            dictionary.get("TargetUniqueClientId")\
            if dictionary.get("TargetUniqueClientId")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(source_site_id,
                   source_client_id,
                   source_unique_client_id,
                   target_site_id,
                   target_client_id,
                   target_unique_client_id)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _source_site_id=(
            self.source_site_id
            if hasattr(self, "source_site_id")
            else None
        )
        _source_client_id=(
            self.source_client_id
            if hasattr(self, "source_client_id")
            else None
        )
        _source_unique_client_id=(
            self.source_unique_client_id
            if hasattr(self, "source_unique_client_id")
            else None
        )
        _target_site_id=(
            self.target_site_id
            if hasattr(self, "target_site_id")
            else None
        )
        _target_client_id=(
            self.target_client_id
            if hasattr(self, "target_client_id")
            else None
        )
        _target_unique_client_id=(
            self.target_unique_client_id
            if hasattr(self, "target_unique_client_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"source_site_id={_source_site_id!r}, "
            f"source_client_id={_source_client_id!r}, "
            f"source_unique_client_id={_source_unique_client_id!r}, "
            f"target_site_id={_target_site_id!r}, "
            f"target_client_id={_target_client_id!r}, "
            f"target_unique_client_id={_target_unique_client_id!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _source_site_id=(
            self.source_site_id
            if hasattr(self, "source_site_id")
            else None
        )
        _source_client_id=(
            self.source_client_id
            if hasattr(self, "source_client_id")
            else None
        )
        _source_unique_client_id=(
            self.source_unique_client_id
            if hasattr(self, "source_unique_client_id")
            else None
        )
        _target_site_id=(
            self.target_site_id
            if hasattr(self, "target_site_id")
            else None
        )
        _target_client_id=(
            self.target_client_id
            if hasattr(self, "target_client_id")
            else None
        )
        _target_unique_client_id=(
            self.target_unique_client_id
            if hasattr(self, "target_unique_client_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"source_site_id={_source_site_id!s}, "
            f"source_client_id={_source_client_id!s}, "
            f"source_unique_client_id={_source_unique_client_id!s}, "
            f"target_site_id={_target_site_id!s}, "
            f"target_client_id={_target_client_id!s}, "
            f"target_unique_client_id={_target_unique_client_id!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class UpdateProductRequest(object):
    """Implementation of the 'UpdateProductRequest' model.

    Update Product Request Model

    Attributes:
        barcode_id (str): The unique ID of the product variant, for example, a
            particular size and color combination.
        price (float): The price of the product.
        online_price (float): The online price of the product.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "barcode_id": "BarcodeId",
        "price": "Price",
        "online_price": "OnlinePrice",
    }

    _optionals = [
        "barcode_id",
        "price",
        "online_price",
    ]

    def __init__(
        self,
        barcode_id=APIHelper.SKIP,
        price=APIHelper.SKIP,
        online_price=APIHelper.SKIP):
        """Initialize a UpdateProductRequest instance."""
        # Initialize members of the class
        if barcode_id is not APIHelper.SKIP:
            self.barcode_id = barcode_id
        if price is not APIHelper.SKIP:
            self.price = price
        if online_price is not APIHelper.SKIP:
            self.online_price = online_price

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        barcode_id =\
            dictionary.get("BarcodeId")\
            if dictionary.get("BarcodeId")\
                else APIHelper.SKIP
        price =\
            dictionary.get("Price")\
            if dictionary.get("Price")\
                else APIHelper.SKIP
        online_price =\
            dictionary.get("OnlinePrice")\
            if dictionary.get("OnlinePrice")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(barcode_id,
                   price,
                   online_price)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _barcode_id=(
            self.barcode_id
            if hasattr(self, "barcode_id")
            else None
        )
        _price=(
            self.price
            if hasattr(self, "price")
            else None
        )
        _online_price=(
            self.online_price
            if hasattr(self, "online_price")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"barcode_id={_barcode_id!r}, "
            f"price={_price!r}, "
            f"online_price={_online_price!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _barcode_id=(
            self.barcode_id
            if hasattr(self, "barcode_id")
            else None
        )
        _price=(
            self.price
            if hasattr(self, "price")
            else None
        )
        _online_price=(
            self.online_price
            if hasattr(self, "online_price")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"barcode_id={_barcode_id!s}, "
            f"price={_price!s}, "
            f"online_price={_online_price!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.sale import Sale


class ClientPurchaseRecord(object):
    """Implementation of the 'ClientPurchaseRecord' model.

    A record of a specific client purchase

    Attributes:
        sale (Sale): Contains the Sale details.
        description (str): The item name and description.
        account_payment (bool): If `true`, the item was a payment credited to an
            account.
        price (float): The price paid for the item.
        amount_paid (float): The amount paid for the item.
        discount (float): The discount amount that was applied to the item.
        tax (float): The amount of tax that was applied to the item.
        returned (bool): The return status of the item. If `true`, this item was
            returned.
        quantity (int): The quantity of the item purchased.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "sale": "Sale",
        "description": "Description",
        "account_payment": "AccountPayment",
        "price": "Price",
        "amount_paid": "AmountPaid",
        "discount": "Discount",
        "tax": "Tax",
        "returned": "Returned",
        "quantity": "Quantity",
    }

    _optionals = [
        "sale",
        "description",
        "account_payment",
        "price",
        "amount_paid",
        "discount",
        "tax",
        "returned",
        "quantity",
    ]

    def __init__(
        self,
        sale=APIHelper.SKIP,
        description=APIHelper.SKIP,
        account_payment=APIHelper.SKIP,
        price=APIHelper.SKIP,
        amount_paid=APIHelper.SKIP,
        discount=APIHelper.SKIP,
        tax=APIHelper.SKIP,
        returned=APIHelper.SKIP,
        quantity=APIHelper.SKIP):
        """Initialize a ClientPurchaseRecord instance."""
        # Initialize members of the class
        if sale is not APIHelper.SKIP:
            self.sale = sale
        if description is not APIHelper.SKIP:
            self.description = description
        if account_payment is not APIHelper.SKIP:
            self.account_payment = account_payment
        if price is not APIHelper.SKIP:
            self.price = price
        if amount_paid is not APIHelper.SKIP:
            self.amount_paid = amount_paid
        if discount is not APIHelper.SKIP:
            self.discount = discount
        if tax is not APIHelper.SKIP:
            self.tax = tax
        if returned is not APIHelper.SKIP:
            self.returned = returned
        if quantity is not APIHelper.SKIP:
            self.quantity = quantity

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        sale =\
            Sale.from_dictionary(
                dictionary.get("Sale"))\
                if "Sale" in dictionary.keys()\
                else APIHelper.SKIP
        description =\
            dictionary.get("Description")\
            if dictionary.get("Description")\
                else APIHelper.SKIP
        account_payment =\
            dictionary.get("AccountPayment")\
            if "AccountPayment" in dictionary.keys()\
                else APIHelper.SKIP
        price =\
            dictionary.get("Price")\
            if dictionary.get("Price")\
                else APIHelper.SKIP
        amount_paid =\
            dictionary.get("AmountPaid")\
            if dictionary.get("AmountPaid")\
                else APIHelper.SKIP
        discount =\
            dictionary.get("Discount")\
            if dictionary.get("Discount")\
                else APIHelper.SKIP
        tax =\
            dictionary.get("Tax")\
            if dictionary.get("Tax")\
                else APIHelper.SKIP
        returned =\
            dictionary.get("Returned")\
            if "Returned" in dictionary.keys()\
                else APIHelper.SKIP
        quantity =\
            dictionary.get("Quantity")\
            if dictionary.get("Quantity")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(sale,
                   description,
                   account_payment,
                   price,
                   amount_paid,
                   discount,
                   tax,
                   returned,
                   quantity)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _sale=(
            self.sale
            if hasattr(self, "sale")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _account_payment=(
            self.account_payment
            if hasattr(self, "account_payment")
            else None
        )
        _price=(
            self.price
            if hasattr(self, "price")
            else None
        )
        _amount_paid=(
            self.amount_paid
            if hasattr(self, "amount_paid")
            else None
        )
        _discount=(
            self.discount
            if hasattr(self, "discount")
            else None
        )
        _tax=(
            self.tax
            if hasattr(self, "tax")
            else None
        )
        _returned=(
            self.returned
            if hasattr(self, "returned")
            else None
        )
        _quantity=(
            self.quantity
            if hasattr(self, "quantity")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"sale={_sale!r}, "
            f"description={_description!r}, "
            f"account_payment={_account_payment!r}, "
            f"price={_price!r}, "
            f"amount_paid={_amount_paid!r}, "
            f"discount={_discount!r}, "
            f"tax={_tax!r}, "
            f"returned={_returned!r}, "
            f"quantity={_quantity!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _sale=(
            self.sale
            if hasattr(self, "sale")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _account_payment=(
            self.account_payment
            if hasattr(self, "account_payment")
            else None
        )
        _price=(
            self.price
            if hasattr(self, "price")
            else None
        )
        _amount_paid=(
            self.amount_paid
            if hasattr(self, "amount_paid")
            else None
        )
        _discount=(
            self.discount
            if hasattr(self, "discount")
            else None
        )
        _tax=(
            self.tax
            if hasattr(self, "tax")
            else None
        )
        _returned=(
            self.returned
            if hasattr(self, "returned")
            else None
        )
        _quantity=(
            self.quantity
            if hasattr(self, "quantity")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"sale={_sale!s}, "
            f"description={_description!s}, "
            f"account_payment={_account_payment!s}, "
            f"price={_price!s}, "
            f"amount_paid={_amount_paid!s}, "
            f"discount={_discount!s}, "
            f"tax={_tax!s}, "
            f"returned={_returned!s}, "
            f"quantity={_quantity!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.mobile_provider import (
    MobileProvider,
)


class GetMobileProvidersResponse(object):
    """Implementation of the 'GetMobileProvidersResponse' model.

    Get Mobile Providers Response Object

    Attributes:
        mobile_providers (List[MobileProvider]): A list of mobile providers.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "mobile_providers": "MobileProviders",
    }

    _optionals = [
        "mobile_providers",
    ]

    def __init__(
        self,
        mobile_providers=APIHelper.SKIP):
        """Initialize a GetMobileProvidersResponse instance."""
        # Initialize members of the class
        if mobile_providers is not APIHelper.SKIP:
            self.mobile_providers = mobile_providers

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        mobile_providers = None
        if dictionary.get("MobileProviders") is not None:
            mobile_providers = [
                MobileProvider.from_dictionary(x)
                    for x in dictionary.get("MobileProviders")
            ]
        else:
            mobile_providers = APIHelper.SKIP

        # Return an object of this model
        return cls(mobile_providers)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _mobile_providers=(
            self.mobile_providers
            if hasattr(self, "mobile_providers")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"mobile_providers={_mobile_providers!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _mobile_providers=(
            self.mobile_providers
            if hasattr(self, "mobile_providers")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"mobile_providers={_mobile_providers!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.alternative_payment_method import (
    AlternativePaymentMethod,
)


class GetAlternativePaymentMethodsResponse(object):
    """Implementation of the 'GetAlternativePaymentMethodsResponse' model.

    Response for the GetAlternativePaymentMethods method.

    Attributes:
        payment_methods (List[AlternativePaymentMethod]): Contains information about
            the alternative payment methods.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "payment_methods": "PaymentMethods",
    }

    _optionals = [
        "payment_methods",
    ]

    def __init__(
        self,
        payment_methods=APIHelper.SKIP):
        """Initialize a GetAlternativePaymentMethodsResponse instance."""
        # Initialize members of the class
        if payment_methods is not APIHelper.SKIP:
            self.payment_methods = payment_methods

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        payment_methods = None
        if dictionary.get("PaymentMethods") is not None:
            payment_methods = [
                AlternativePaymentMethod.from_dictionary(x)
                    for x in dictionary.get("PaymentMethods")
            ]
        else:
            payment_methods = APIHelper.SKIP

        # Return an object of this model
        return cls(payment_methods)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _payment_methods=(
            self.payment_methods
            if hasattr(self, "payment_methods")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"payment_methods={_payment_methods!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _payment_methods=(
            self.payment_methods
            if hasattr(self, "payment_methods")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"payment_methods={_payment_methods!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
class ClassClientDetail(object):
    """Implementation of the 'ClassClientDetail' model.

    Class Client Detail Object

    Attributes:
        client_ids (List[str]): The RSSID of the clients to remove from the specified
            classes.
        class_id (int): The ID of the classes that you want to remove the clients
            from.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_ids": "ClientIds",
        "class_id": "ClassId",
    }

    def __init__(
        self,
        client_ids=None,
        class_id=None):
        """Initialize a ClassClientDetail instance."""
        # Initialize members of the class
        self.client_ids = client_ids
        self.class_id = class_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_ids =\
            dictionary.get("ClientIds")\
            if dictionary.get("ClientIds")\
                else None
        class_id =\
            dictionary.get("ClassId")\
            if dictionary.get("ClassId")\
                else None

        # Return an object of this model
        return cls(client_ids,
                   class_id)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client_ids=self.client_ids
        _class_id=self.class_id
        return (
            f"{self.__class__.__name__}("
            f"client_ids={_client_ids!r}, "
            f"class_id={_class_id!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client_ids=self.client_ids
        _class_id=self.class_id
        return (
            f"{self.__class__.__name__}("
            f"client_ids={_client_ids!s}, "
            f"class_id={_class_id!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetServicesRequest(object):
    """Implementation of the 'GetServicesRequest' model.

    Attributes:
        program_ids (List[int]): Filters to pricing options with the specified
            program IDs.
        session_type_ids (List[int]): Filters to the pricing options with the
            specified session types IDs.
        service_ids (List[str]): Filters to the pricing options with the specified
            IDs. In this context, service and pricing option are used
            interchangeably. These are the `PurchasedItems[].Id` returned from GET
            Sales.
        class_id (int): Filters to the pricing options for the specified class ID.
        class_schedule_id (int): Filters to the pricing options for the specified
            class schedule ID.
        sell_online (bool): When `true`, filters the pricing options to display only
            those available for online purchase.  This parameter is only applicable
            in Business Mode (when a staff authentication header is included) and
            ignored in Consumer Mode (when no authentication header is passed).  <br
            />Default: `false` (for staff users)  <br />Business Mode: This parameter
            controls the filtering behavior. Staff users can set this to `true`  to
            show only pricing options that can be sold online, or `false` to show all
            available pricing options.  <br />Consumer Mode: This value is
            automatically set to `true` and cannot be overridden,  ensuring consumers
            only see pricing options available for online purchase.
        location_id (int): When specified, for each returned pricing option,
            `TaxRate` and `TaxIncluded` are calculated according to the specified
            location. Note that this does not filter results to only services
            provided at the given location, and for locations where Value-Added Tax
            (VAT) rules apply, the `TaxRate` is set to zero.
        hide_related_programs (bool): When `true`, indicates that pricing options of
            related programs are omitted from the response.<br />  Default: **false**
        staff_id (int): Sets `Price` and `OnlinePrice` to the particular pricing of a
            specific staff member, if allowed by the business.
        include_discontinued (bool): When `true`, indicates that the filtered pricing
            option list includes discontinued pricing options.<br />  Default:
            **false**
        include_sale_in_contract_only (bool): When `true`, indicates that the
            filtered pricing option list includes sale in contract only pricing
            options.<br />  Default: **false**
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "program_ids": "ProgramIds",
        "session_type_ids": "SessionTypeIds",
        "service_ids": "ServiceIds",
        "class_id": "ClassId",
        "class_schedule_id": "ClassScheduleId",
        "sell_online": "SellOnline",
        "location_id": "LocationId",
        "hide_related_programs": "HideRelatedPrograms",
        "staff_id": "StaffId",
        "include_discontinued": "IncludeDiscontinued",
        "include_sale_in_contract_only": "IncludeSaleInContractOnly",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "program_ids",
        "session_type_ids",
        "service_ids",
        "class_id",
        "class_schedule_id",
        "sell_online",
        "location_id",
        "hide_related_programs",
        "staff_id",
        "include_discontinued",
        "include_sale_in_contract_only",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        program_ids=APIHelper.SKIP,
        session_type_ids=APIHelper.SKIP,
        service_ids=APIHelper.SKIP,
        class_id=APIHelper.SKIP,
        class_schedule_id=APIHelper.SKIP,
        sell_online=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        hide_related_programs=APIHelper.SKIP,
        staff_id=APIHelper.SKIP,
        include_discontinued=APIHelper.SKIP,
        include_sale_in_contract_only=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetServicesRequest instance."""
        # Initialize members of the class
        if program_ids is not APIHelper.SKIP:
            self.program_ids = program_ids
        if session_type_ids is not APIHelper.SKIP:
            self.session_type_ids = session_type_ids
        if service_ids is not APIHelper.SKIP:
            self.service_ids = service_ids
        if class_id is not APIHelper.SKIP:
            self.class_id = class_id
        if class_schedule_id is not APIHelper.SKIP:
            self.class_schedule_id = class_schedule_id
        if sell_online is not APIHelper.SKIP:
            self.sell_online = sell_online
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if hide_related_programs is not APIHelper.SKIP:
            self.hide_related_programs = hide_related_programs
        if staff_id is not APIHelper.SKIP:
            self.staff_id = staff_id
        if include_discontinued is not APIHelper.SKIP:
            self.include_discontinued = include_discontinued
        if include_sale_in_contract_only is not APIHelper.SKIP:
            self.include_sale_in_contract_only = include_sale_in_contract_only
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        program_ids =\
            dictionary.get("ProgramIds")\
            if dictionary.get("ProgramIds")\
                else APIHelper.SKIP
        session_type_ids =\
            dictionary.get("SessionTypeIds")\
            if dictionary.get("SessionTypeIds")\
                else APIHelper.SKIP
        service_ids =\
            dictionary.get("ServiceIds")\
            if dictionary.get("ServiceIds")\
                else APIHelper.SKIP
        class_id =\
            dictionary.get("ClassId")\
            if dictionary.get("ClassId")\
                else APIHelper.SKIP
        class_schedule_id =\
            dictionary.get("ClassScheduleId")\
            if dictionary.get("ClassScheduleId")\
                else APIHelper.SKIP
        sell_online =\
            dictionary.get("SellOnline")\
            if "SellOnline" in dictionary.keys()\
                else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        hide_related_programs =\
            dictionary.get("HideRelatedPrograms")\
            if "HideRelatedPrograms" in dictionary.keys()\
                else APIHelper.SKIP
        staff_id =\
            dictionary.get("StaffId")\
            if dictionary.get("StaffId")\
                else APIHelper.SKIP
        include_discontinued =\
            dictionary.get("IncludeDiscontinued")\
            if "IncludeDiscontinued" in dictionary.keys()\
                else APIHelper.SKIP
        include_sale_in_contract_only =\
            dictionary.get("IncludeSaleInContractOnly")\
            if "IncludeSaleInContractOnly" in dictionary.keys()\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(program_ids,
                   session_type_ids,
                   service_ids,
                   class_id,
                   class_schedule_id,
                   sell_online,
                   location_id,
                   hide_related_programs,
                   staff_id,
                   include_discontinued,
                   include_sale_in_contract_only,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _program_ids=(
            self.program_ids
            if hasattr(self, "program_ids")
            else None
        )
        _session_type_ids=(
            self.session_type_ids
            if hasattr(self, "session_type_ids")
            else None
        )
        _service_ids=(
            self.service_ids
            if hasattr(self, "service_ids")
            else None
        )
        _class_id=(
            self.class_id
            if hasattr(self, "class_id")
            else None
        )
        _class_schedule_id=(
            self.class_schedule_id
            if hasattr(self, "class_schedule_id")
            else None
        )
        _sell_online=(
            self.sell_online
            if hasattr(self, "sell_online")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _hide_related_programs=(
            self.hide_related_programs
            if hasattr(self, "hide_related_programs")
            else None
        )
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _include_discontinued=(
            self.include_discontinued
            if hasattr(self, "include_discontinued")
            else None
        )
        _include_sale_in_contract_only=(
            self.include_sale_in_contract_only
            if hasattr(self, "include_sale_in_contract_only")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"program_ids={_program_ids!r}, "
            f"session_type_ids={_session_type_ids!r}, "
            f"service_ids={_service_ids!r}, "
            f"class_id={_class_id!r}, "
            f"class_schedule_id={_class_schedule_id!r}, "
            f"sell_online={_sell_online!r}, "
            f"location_id={_location_id!r}, "
            f"hide_related_programs={_hide_related_programs!r}, "
            f"staff_id={_staff_id!r}, "
            f"include_discontinued={_include_discontinued!r}, "
            f"include_sale_in_contract_only={_include_sale_in_contract_only!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _program_ids=(
            self.program_ids
            if hasattr(self, "program_ids")
            else None
        )
        _session_type_ids=(
            self.session_type_ids
            if hasattr(self, "session_type_ids")
            else None
        )
        _service_ids=(
            self.service_ids
            if hasattr(self, "service_ids")
            else None
        )
        _class_id=(
            self.class_id
            if hasattr(self, "class_id")
            else None
        )
        _class_schedule_id=(
            self.class_schedule_id
            if hasattr(self, "class_schedule_id")
            else None
        )
        _sell_online=(
            self.sell_online
            if hasattr(self, "sell_online")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _hide_related_programs=(
            self.hide_related_programs
            if hasattr(self, "hide_related_programs")
            else None
        )
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _include_discontinued=(
            self.include_discontinued
            if hasattr(self, "include_discontinued")
            else None
        )
        _include_sale_in_contract_only=(
            self.include_sale_in_contract_only
            if hasattr(self, "include_sale_in_contract_only")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"program_ids={_program_ids!s}, "
            f"session_type_ids={_session_type_ids!s}, "
            f"service_ids={_service_ids!s}, "
            f"class_id={_class_id!s}, "
            f"class_schedule_id={_class_schedule_id!s}, "
            f"sell_online={_sell_online!s}, "
            f"location_id={_location_id!s}, "
            f"hide_related_programs={_hide_related_programs!s}, "
            f"staff_id={_staff_id!s}, "
            f"include_discontinued={_include_discontinued!s}, "
            f"include_sale_in_contract_only={_include_sale_in_contract_only!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



# ruff: noqa: D104 | Missing docstring in public package
# ruff: noqa: RUF022 | `__all__` is not sorted
__all__ = [
    "auth",
    "http_call_back",
    "http_client_provider",
    "http_method_enum",
    "http_request",
    "http_response",
    "proxy_settings",
]



"""
mindbodypublicapi

This file was automatically generated by APIMATIC v3.0 (
 https://www.apimatic.io ).
"""

import os
from typing import Optional

from apimatic_core.http.configurations.proxy_settings import (
    ProxySettings as CoreProxySettings,
)


class ProxySettings(CoreProxySettings):
    """A simple data model for configuring HTTP(S) proxy settings."""

    @classmethod
    def from_environment(cls) -> Optional["ProxySettings"]:
        """
        Create an instance of this class using environment-based configuration.

        This method attempts to construct and return an instance using relevant
        environment variables, if available. If the required configuration is
        not present, it may return `None` to indicate that no valid instance
        could be created.

        Returns:
            Optional[cls]: A configured instance of this class, or `None` if
            configuration data is missing or invalid.

        """
        address = os.getenv("PROXY_ADDRESS", None)
        if not address:
            return None

        port = os.getenv("PROXY_PORT", None)
        if port is not None:
            try:
                port = int(port)
            except (TypeError, ValueError):
                port = None

        return cls(
            address=address,
            port=port,
            username=os.getenv("PROXY_USERNAME", None),
            password=os.getenv("PROXY_PASSWORD", None),
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class ResponseDetails(object):
    """Implementation of the 'ResponseDetails' model.

    Contains information about the response message detail.

    Attributes:
        status (str): Contains information about the response status.
        transaction_id (str): The unique transaction ID.
        message (str): Contains information about the response message detail.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "status": "Status",
        "transaction_id": "TransactionId",
        "message": "Message",
    }

    _optionals = [
        "status",
        "transaction_id",
        "message",
    ]

    def __init__(
        self,
        status=APIHelper.SKIP,
        transaction_id=APIHelper.SKIP,
        message=APIHelper.SKIP):
        """Initialize a ResponseDetails instance."""
        # Initialize members of the class
        if status is not APIHelper.SKIP:
            self.status = status
        if transaction_id is not APIHelper.SKIP:
            self.transaction_id = transaction_id
        if message is not APIHelper.SKIP:
            self.message = message

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        status =\
            dictionary.get("Status")\
            if dictionary.get("Status")\
                else APIHelper.SKIP
        transaction_id =\
            dictionary.get("TransactionId")\
            if dictionary.get("TransactionId")\
                else APIHelper.SKIP
        message =\
            dictionary.get("Message")\
            if dictionary.get("Message")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(status,
                   transaction_id,
                   message)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _status=(
            self.status
            if hasattr(self, "status")
            else None
        )
        _transaction_id=(
            self.transaction_id
            if hasattr(self, "transaction_id")
            else None
        )
        _message=(
            self.message
            if hasattr(self, "message")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"status={_status!r}, "
            f"transaction_id={_transaction_id!r}, "
            f"message={_message!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _status=(
            self.status
            if hasattr(self, "status")
            else None
        )
        _transaction_id=(
            self.transaction_id
            if hasattr(self, "transaction_id")
            else None
        )
        _message=(
            self.message
            if hasattr(self, "message")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"status={_status!s}, "
            f"transaction_id={_transaction_id!s}, "
            f"message={_message!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetClientCompleteInfoRequest(object):
    """Implementation of the 'GetClientCompleteInfoRequest' model.

    request for GetClientCompleteInfoRequest

    Attributes:
        client_id (str): Filters results to client with these ID.
        start_date (datetime): Filters results to pricing options that are purchased
            on or after this date.   Default: **today’s date**.
        end_date (datetime): Filters results to pricing options that are purchased on
            or before this date.   Default: **today’s date**.
        cross_regional_lookup (bool): Used to retrieve a clients pricing options from
            multiple sites within an organization.When included and set to `true`,
            it searches a maximum of ten sites with which this client is
            associated.When a client is associated with more than ten sites, use
            `ClientAssociatedSitesOffset` as many times as needed to search the
            additional sites with which the client is associated.  You can use the
            `CrossRegionalClientAssociations` value from `GET
            CrossRegionalClientAssociations` to determine how many sites the client
            is associated with.   Note that a `SiteID` is returned and populated in
            the `ClientServices` response when `CrossRegionalLookup` is set to
            `true`.   Default: **false**
        client_associated_sites_offset (int): Used to retrieve a client’s pricing
            options from multiple sites within an organization when the client is
            associated with more than ten sites. To change which ten sites are
            searched, change this offset value. A value of 0 means that no sites are
            skipped and the first ten sites are returned. You can use the
            `CrossRegionalClientAssociations` value from `GET
            CrossRegionalClientAssociations` to determine how many sites the client
            is associated with. Note that you must always have `CrossRegionalLookup`
            set to `true` to use this parameter.<br />  Default: **0**    For
            example, if a client is associated with 25 sites, you need to call
            `GetClientServices` three times, as follows:  * Use `GET
            CrossRegionalClientAssociations` to determine how many sites a client is
            associated with, which tells you how many additional calls you need to
            make.  * Either omit `ClientAssociatedSitesOffset` or set it to 0 to
            return the client’s services (pricing options) from sites 1-10.  * Set
            `ClientAssociatedSitesOffset` to 10 to return the client pricing options
            from sites 11-20  * Set `ClientAssociatedSitesOffset` to 20 to return the
            client pricing options from sites 21-25
        required_client_data (List[str]): Used to retrieve list of purchased
            services, contract details, membership details and arrival programs for a
            specific client.   Default `ClientServices`, `ClientContracts`,
            `ClientMemberships` and `ClientArrivals` will be returned when
            `RequiredClientDatais` not set.   When `RequiredClientData` is set to
            `Contracts` then only `ClientContracts` will be returned in the response.
            When `RequiredClientData` is set to Services then only `ClientServices`
            will be returned in the response.  When `RequiredClientData` is set to
            `Memberships` then only `ClientMemberships` will be returned in the
            response.   When `RequiredClientData` is set to `ArrivalPrograms` then
            only `ClientArrivals` will be returned in the response.
        exclude_inactive_sites (bool): When this flag is set to `true`, will exclude
            inactive sites from the response  Default: **false**
        use_activate_date (bool): When this flag is set to `true`, the date filtering
            will use activate date to filter the pricing options.  When this flag is
            set to `false`, the date filtering will use purchase date to filter the
            pricing options.  Default: **false**
        show_active_only (bool): When `true`, includes active services only. Set this
            field to `true` when trying to determine if a client has a   service that
            can pay for a class or appointment.  Default: **false**
        unique_client_id (int): The unique ID of the client who is viewing this class
            list.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_id": "ClientId",
        "start_date": "StartDate",
        "end_date": "EndDate",
        "cross_regional_lookup": "CrossRegionalLookup",
        "client_associated_sites_offset": "ClientAssociatedSitesOffset",
        "required_client_data": "RequiredClientData",
        "exclude_inactive_sites": "ExcludeInactiveSites",
        "use_activate_date": "UseActivateDate",
        "show_active_only": "ShowActiveOnly",
        "unique_client_id": "UniqueClientId",
    }

    _optionals = [
        "start_date",
        "end_date",
        "cross_regional_lookup",
        "client_associated_sites_offset",
        "required_client_data",
        "exclude_inactive_sites",
        "use_activate_date",
        "show_active_only",
        "unique_client_id",
    ]

    def __init__(
        self,
        client_id=None,
        start_date=APIHelper.SKIP,
        end_date=APIHelper.SKIP,
        cross_regional_lookup=APIHelper.SKIP,
        client_associated_sites_offset=APIHelper.SKIP,
        required_client_data=APIHelper.SKIP,
        exclude_inactive_sites=APIHelper.SKIP,
        use_activate_date=APIHelper.SKIP,
        show_active_only=APIHelper.SKIP,
        unique_client_id=APIHelper.SKIP):
        """Initialize a GetClientCompleteInfoRequest instance."""
        # Initialize members of the class
        self.client_id = client_id
        if start_date is not APIHelper.SKIP:
            self.start_date =\
                 APIHelper.apply_datetime_converter(
                start_date, APIHelper.RFC3339DateTime)\
                 if start_date else None
        if end_date is not APIHelper.SKIP:
            self.end_date =\
                 APIHelper.apply_datetime_converter(
                end_date, APIHelper.RFC3339DateTime)\
                 if end_date else None
        if cross_regional_lookup is not APIHelper.SKIP:
            self.cross_regional_lookup = cross_regional_lookup
        if client_associated_sites_offset is not APIHelper.SKIP:
            self.client_associated_sites_offset = client_associated_sites_offset
        if required_client_data is not APIHelper.SKIP:
            self.required_client_data = required_client_data
        if exclude_inactive_sites is not APIHelper.SKIP:
            self.exclude_inactive_sites = exclude_inactive_sites
        if use_activate_date is not APIHelper.SKIP:
            self.use_activate_date = use_activate_date
        if show_active_only is not APIHelper.SKIP:
            self.show_active_only = show_active_only
        if unique_client_id is not APIHelper.SKIP:
            self.unique_client_id = unique_client_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else None
        start_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDate")).datetime\
            if dictionary.get("StartDate") else APIHelper.SKIP
        end_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDate")).datetime\
            if dictionary.get("EndDate") else APIHelper.SKIP
        cross_regional_lookup =\
            dictionary.get("CrossRegionalLookup")\
            if "CrossRegionalLookup" in dictionary.keys()\
                else APIHelper.SKIP
        client_associated_sites_offset =\
            dictionary.get("ClientAssociatedSitesOffset")\
            if dictionary.get("ClientAssociatedSitesOffset")\
                else APIHelper.SKIP
        required_client_data =\
            dictionary.get("RequiredClientData")\
            if dictionary.get("RequiredClientData")\
                else APIHelper.SKIP
        exclude_inactive_sites =\
            dictionary.get("ExcludeInactiveSites")\
            if "ExcludeInactiveSites" in dictionary.keys()\
                else APIHelper.SKIP
        use_activate_date =\
            dictionary.get("UseActivateDate")\
            if "UseActivateDate" in dictionary.keys()\
                else APIHelper.SKIP
        show_active_only =\
            dictionary.get("ShowActiveOnly")\
            if "ShowActiveOnly" in dictionary.keys()\
                else APIHelper.SKIP
        unique_client_id =\
            dictionary.get("UniqueClientId")\
            if dictionary.get("UniqueClientId")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client_id,
                   start_date,
                   end_date,
                   cross_regional_lookup,
                   client_associated_sites_offset,
                   required_client_data,
                   exclude_inactive_sites,
                   use_activate_date,
                   show_active_only,
                   unique_client_id)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client_id=self.client_id
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _cross_regional_lookup=(
            self.cross_regional_lookup
            if hasattr(self, "cross_regional_lookup")
            else None
        )
        _client_associated_sites_offset=(
            self.client_associated_sites_offset
            if hasattr(self, "client_associated_sites_offset")
            else None
        )
        _required_client_data=(
            self.required_client_data
            if hasattr(self, "required_client_data")
            else None
        )
        _exclude_inactive_sites=(
            self.exclude_inactive_sites
            if hasattr(self, "exclude_inactive_sites")
            else None
        )
        _use_activate_date=(
            self.use_activate_date
            if hasattr(self, "use_activate_date")
            else None
        )
        _show_active_only=(
            self.show_active_only
            if hasattr(self, "show_active_only")
            else None
        )
        _unique_client_id=(
            self.unique_client_id
            if hasattr(self, "unique_client_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!r}, "
            f"start_date={_start_date!r}, "
            f"end_date={_end_date!r}, "
            f"cross_regional_lookup={_cross_regional_lookup!r}, "
            f"client_associated_sites_offset={_client_associated_sites_offset!r}, "
            f"required_client_data={_required_client_data!r}, "
            f"exclude_inactive_sites={_exclude_inactive_sites!r}, "
            f"use_activate_date={_use_activate_date!r}, "
            f"show_active_only={_show_active_only!r}, "
            f"unique_client_id={_unique_client_id!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client_id=self.client_id
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _cross_regional_lookup=(
            self.cross_regional_lookup
            if hasattr(self, "cross_regional_lookup")
            else None
        )
        _client_associated_sites_offset=(
            self.client_associated_sites_offset
            if hasattr(self, "client_associated_sites_offset")
            else None
        )
        _required_client_data=(
            self.required_client_data
            if hasattr(self, "required_client_data")
            else None
        )
        _exclude_inactive_sites=(
            self.exclude_inactive_sites
            if hasattr(self, "exclude_inactive_sites")
            else None
        )
        _use_activate_date=(
            self.use_activate_date
            if hasattr(self, "use_activate_date")
            else None
        )
        _show_active_only=(
            self.show_active_only
            if hasattr(self, "show_active_only")
            else None
        )
        _unique_client_id=(
            self.unique_client_id
            if hasattr(self, "unique_client_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_id={_client_id!s}, "
            f"start_date={_start_date!s}, "
            f"end_date={_end_date!s}, "
            f"cross_regional_lookup={_cross_regional_lookup!s}, "
            f"client_associated_sites_offset={_client_associated_sites_offset!s}, "
            f"required_client_data={_required_client_data!s}, "
            f"exclude_inactive_sites={_exclude_inactive_sites!s}, "
            f"use_activate_date={_use_activate_date!s}, "
            f"show_active_only={_show_active_only!s}, "
            f"unique_client_id={_unique_client_id!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.reservation import (
    Reservation,
)
from mindbodypublicapi.models.spot import Spot


class PickASpotClass(object):
    """Implementation of the 'PickASpotClass' model.

    Contains information about the PickASpot classes.

    Attributes:
        site_id (int): The unique ID of the Site.
        location_id (int): The unique ID of the Location.
        class_id (str): The unique ID of the Class.
        class_external_id (str): The unique Class external ID.
        class_name (str): Contains the class name.
        class_start_time (datetime): Class start time.
        class_end_time (datetime): Class end time.
        class_maximum_capacity (int): Contains information about the Class maximum
            capacity.
        room_id (str): The unique Room ID.
        spots (Spot): Contains information about the spot details.
        reservations (List[Reservation]): Contains information about the reservation
            collection.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "site_id": "SiteId",
        "location_id": "LocationId",
        "class_id": "ClassId",
        "class_external_id": "ClassExternalId",
        "class_name": "ClassName",
        "class_start_time": "ClassStartTime",
        "class_end_time": "ClassEndTime",
        "class_maximum_capacity": "ClassMaximumCapacity",
        "room_id": "RoomId",
        "spots": "Spots",
        "reservations": "Reservations",
    }

    _optionals = [
        "site_id",
        "location_id",
        "class_id",
        "class_external_id",
        "class_name",
        "class_start_time",
        "class_end_time",
        "class_maximum_capacity",
        "room_id",
        "spots",
        "reservations",
    ]

    def __init__(
        self,
        site_id=APIHelper.SKIP,
        location_id=APIHelper.SKIP,
        class_id=APIHelper.SKIP,
        class_external_id=APIHelper.SKIP,
        class_name=APIHelper.SKIP,
        class_start_time=APIHelper.SKIP,
        class_end_time=APIHelper.SKIP,
        class_maximum_capacity=APIHelper.SKIP,
        room_id=APIHelper.SKIP,
        spots=APIHelper.SKIP,
        reservations=APIHelper.SKIP):
        """Initialize a PickASpotClass instance."""
        # Initialize members of the class
        if site_id is not APIHelper.SKIP:
            self.site_id = site_id
        if location_id is not APIHelper.SKIP:
            self.location_id = location_id
        if class_id is not APIHelper.SKIP:
            self.class_id = class_id
        if class_external_id is not APIHelper.SKIP:
            self.class_external_id = class_external_id
        if class_name is not APIHelper.SKIP:
            self.class_name = class_name
        if class_start_time is not APIHelper.SKIP:
            self.class_start_time =\
                 APIHelper.apply_datetime_converter(
                class_start_time, APIHelper.RFC3339DateTime)\
                 if class_start_time else None
        if class_end_time is not APIHelper.SKIP:
            self.class_end_time =\
                 APIHelper.apply_datetime_converter(
                class_end_time, APIHelper.RFC3339DateTime)\
                 if class_end_time else None
        if class_maximum_capacity is not APIHelper.SKIP:
            self.class_maximum_capacity = class_maximum_capacity
        if room_id is not APIHelper.SKIP:
            self.room_id = room_id
        if spots is not APIHelper.SKIP:
            self.spots = spots
        if reservations is not APIHelper.SKIP:
            self.reservations = reservations

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        site_id =\
            dictionary.get("SiteId")\
            if dictionary.get("SiteId")\
                else APIHelper.SKIP
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else APIHelper.SKIP
        class_id =\
            dictionary.get("ClassId")\
            if dictionary.get("ClassId")\
                else APIHelper.SKIP
        class_external_id =\
            dictionary.get("ClassExternalId")\
            if dictionary.get("ClassExternalId")\
                else APIHelper.SKIP
        class_name =\
            dictionary.get("ClassName")\
            if dictionary.get("ClassName")\
                else APIHelper.SKIP
        class_start_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("ClassStartTime")).datetime\
            if dictionary.get("ClassStartTime") else APIHelper.SKIP
        class_end_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("ClassEndTime")).datetime\
            if dictionary.get("ClassEndTime") else APIHelper.SKIP
        class_maximum_capacity =\
            dictionary.get("ClassMaximumCapacity")\
            if dictionary.get("ClassMaximumCapacity")\
                else APIHelper.SKIP
        room_id =\
            dictionary.get("RoomId")\
            if dictionary.get("RoomId")\
                else APIHelper.SKIP
        spots =\
            Spot.from_dictionary(
                dictionary.get("Spots"))\
                if "Spots" in dictionary.keys()\
                else APIHelper.SKIP
        reservations = None
        if dictionary.get("Reservations") is not None:
            reservations = [
                Reservation.from_dictionary(x)
                    for x in dictionary.get("Reservations")
            ]
        else:
            reservations = APIHelper.SKIP

        # Return an object of this model
        return cls(site_id,
                   location_id,
                   class_id,
                   class_external_id,
                   class_name,
                   class_start_time,
                   class_end_time,
                   class_maximum_capacity,
                   room_id,
                   spots,
                   reservations)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _site_id=(
            self.site_id
            if hasattr(self, "site_id")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _class_id=(
            self.class_id
            if hasattr(self, "class_id")
            else None
        )
        _class_external_id=(
            self.class_external_id
            if hasattr(self, "class_external_id")
            else None
        )
        _class_name=(
            self.class_name
            if hasattr(self, "class_name")
            else None
        )
        _class_start_time=(
            self.class_start_time
            if hasattr(self, "class_start_time")
            else None
        )
        _class_end_time=(
            self.class_end_time
            if hasattr(self, "class_end_time")
            else None
        )
        _class_maximum_capacity=(
            self.class_maximum_capacity
            if hasattr(self, "class_maximum_capacity")
            else None
        )
        _room_id=(
            self.room_id
            if hasattr(self, "room_id")
            else None
        )
        _spots=(
            self.spots
            if hasattr(self, "spots")
            else None
        )
        _reservations=(
            self.reservations
            if hasattr(self, "reservations")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"site_id={_site_id!r}, "
            f"location_id={_location_id!r}, "
            f"class_id={_class_id!r}, "
            f"class_external_id={_class_external_id!r}, "
            f"class_name={_class_name!r}, "
            f"class_start_time={_class_start_time!r}, "
            f"class_end_time={_class_end_time!r}, "
            f"class_maximum_capacity={_class_maximum_capacity!r}, "
            f"room_id={_room_id!r}, "
            f"spots={_spots!r}, "
            f"reservations={_reservations!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _site_id=(
            self.site_id
            if hasattr(self, "site_id")
            else None
        )
        _location_id=(
            self.location_id
            if hasattr(self, "location_id")
            else None
        )
        _class_id=(
            self.class_id
            if hasattr(self, "class_id")
            else None
        )
        _class_external_id=(
            self.class_external_id
            if hasattr(self, "class_external_id")
            else None
        )
        _class_name=(
            self.class_name
            if hasattr(self, "class_name")
            else None
        )
        _class_start_time=(
            self.class_start_time
            if hasattr(self, "class_start_time")
            else None
        )
        _class_end_time=(
            self.class_end_time
            if hasattr(self, "class_end_time")
            else None
        )
        _class_maximum_capacity=(
            self.class_maximum_capacity
            if hasattr(self, "class_maximum_capacity")
            else None
        )
        _room_id=(
            self.room_id
            if hasattr(self, "room_id")
            else None
        )
        _spots=(
            self.spots
            if hasattr(self, "spots")
            else None
        )
        _reservations=(
            self.reservations
            if hasattr(self, "reservations")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"site_id={_site_id!s}, "
            f"location_id={_location_id!s}, "
            f"class_id={_class_id!s}, "
            f"class_external_id={_class_external_id!s}, "
            f"class_name={_class_name!s}, "
            f"class_start_time={_class_start_time!s}, "
            f"class_end_time={_class_end_time!s}, "
            f"class_maximum_capacity={_class_maximum_capacity!s}, "
            f"room_id={_room_id!s}, "
            f"spots={_spots!s}, "
            f"reservations={_reservations!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class UpdateClientServiceRequest(object):
    """Implementation of the 'UpdateClientServiceRequest' model.

    Attributes:
        service_id (int): The ID of the service to update.
        active_date (datetime): The date that the service became active.
        expiration_date (datetime): The date that the service is to expire.
        count (int): The number of client service sessions to update.
        test (bool): When `true`, indicates that input information is to be
            validated, but not committed.<br />  When `false` or omitted, the
            database is affected.<br />  Default: **false**

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "service_id": "ServiceId",
        "active_date": "ActiveDate",
        "expiration_date": "ExpirationDate",
        "count": "Count",
        "test": "Test",
    }

    _optionals = [
        "active_date",
        "expiration_date",
        "count",
        "test",
    ]

    def __init__(
        self,
        service_id=None,
        active_date=APIHelper.SKIP,
        expiration_date=APIHelper.SKIP,
        count=APIHelper.SKIP,
        test=APIHelper.SKIP):
        """Initialize a UpdateClientServiceRequest instance."""
        # Initialize members of the class
        self.service_id = service_id
        if active_date is not APIHelper.SKIP:
            self.active_date =\
                 APIHelper.apply_datetime_converter(
                active_date, APIHelper.RFC3339DateTime)\
                 if active_date else None
        if expiration_date is not APIHelper.SKIP:
            self.expiration_date =\
                 APIHelper.apply_datetime_converter(
                expiration_date, APIHelper.RFC3339DateTime)\
                 if expiration_date else None
        if count is not APIHelper.SKIP:
            self.count = count
        if test is not APIHelper.SKIP:
            self.test = test

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        service_id =\
            dictionary.get("ServiceId")\
            if dictionary.get("ServiceId")\
                else None
        active_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("ActiveDate")).datetime\
            if dictionary.get("ActiveDate") else APIHelper.SKIP
        expiration_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("ExpirationDate")).datetime\
            if dictionary.get("ExpirationDate") else APIHelper.SKIP
        count =\
            dictionary.get("Count")\
            if dictionary.get("Count")\
                else APIHelper.SKIP
        test =\
            dictionary.get("Test")\
            if "Test" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(service_id,
                   active_date,
                   expiration_date,
                   count,
                   test)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _service_id=self.service_id
        _active_date=(
            self.active_date
            if hasattr(self, "active_date")
            else None
        )
        _expiration_date=(
            self.expiration_date
            if hasattr(self, "expiration_date")
            else None
        )
        _count=(
            self.count
            if hasattr(self, "count")
            else None
        )
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"service_id={_service_id!r}, "
            f"active_date={_active_date!r}, "
            f"expiration_date={_expiration_date!r}, "
            f"count={_count!r}, "
            f"test={_test!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _service_id=self.service_id
        _active_date=(
            self.active_date
            if hasattr(self, "active_date")
            else None
        )
        _expiration_date=(
            self.expiration_date
            if hasattr(self, "expiration_date")
            else None
        )
        _count=(
            self.count
            if hasattr(self, "count")
            else None
        )
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"service_id={_service_id!s}, "
            f"active_date={_active_date!s}, "
            f"expiration_date={_expiration_date!s}, "
            f"count={_count!s}, "
            f"test={_test!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.pricing_relationships import (
    PricingRelationships,
)


class Program(object):
    """Implementation of the 'Program' model.

    Attributes:
        id (int): The service category’s ID.
        name (str): The name of this service category.
        schedule_type (ScheduleTypeEnum): The service category’s schedule type.
            Possible values are:  * All  * Class  * Enrollment  * Appointment  *
            Resource  * Arrival
        cancel_offset (int): The offset to use for the service category.
        content_formats (List[str]): The content delivery platform(s) used by the
            service category. Possible values are:  * InPerson  * Livestream:Mindbody
            * Livestream:Other
        pricing_relationships (PricingRelationships): The model property of type
            PricingRelationships.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": "Id",
        "name": "Name",
        "schedule_type": "ScheduleType",
        "cancel_offset": "CancelOffset",
        "content_formats": "ContentFormats",
        "pricing_relationships": "PricingRelationships",
    }

    _optionals = [
        "id",
        "name",
        "schedule_type",
        "cancel_offset",
        "content_formats",
        "pricing_relationships",
    ]

    def __init__(
        self,
        id=APIHelper.SKIP,
        name=APIHelper.SKIP,
        schedule_type=APIHelper.SKIP,
        cancel_offset=APIHelper.SKIP,
        content_formats=APIHelper.SKIP,
        pricing_relationships=APIHelper.SKIP):
        """Initialize a Program instance."""
        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id
        if name is not APIHelper.SKIP:
            self.name = name
        if schedule_type is not APIHelper.SKIP:
            self.schedule_type = schedule_type
        if cancel_offset is not APIHelper.SKIP:
            self.cancel_offset = cancel_offset
        if content_formats is not APIHelper.SKIP:
            self.content_formats = content_formats
        if pricing_relationships is not APIHelper.SKIP:
            self.pricing_relationships = pricing_relationships

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        name =\
            dictionary.get("Name")\
            if dictionary.get("Name")\
                else APIHelper.SKIP
        schedule_type =\
            dictionary.get("ScheduleType")\
            if dictionary.get("ScheduleType")\
                else APIHelper.SKIP
        cancel_offset =\
            dictionary.get("CancelOffset")\
            if dictionary.get("CancelOffset")\
                else APIHelper.SKIP
        content_formats =\
            dictionary.get("ContentFormats")\
            if dictionary.get("ContentFormats")\
                else APIHelper.SKIP
        pricing_relationships =\
            PricingRelationships.from_dictionary(
                dictionary.get("PricingRelationships"))\
                if "PricingRelationships" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(id,
                   name,
                   schedule_type,
                   cancel_offset,
                   content_formats,
                   pricing_relationships)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _schedule_type=(
            self.schedule_type
            if hasattr(self, "schedule_type")
            else None
        )
        _cancel_offset=(
            self.cancel_offset
            if hasattr(self, "cancel_offset")
            else None
        )
        _content_formats=(
            self.content_formats
            if hasattr(self, "content_formats")
            else None
        )
        _pricing_relationships=(
            self.pricing_relationships
            if hasattr(self, "pricing_relationships")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!r}, "
            f"name={_name!r}, "
            f"schedule_type={_schedule_type!r}, "
            f"cancel_offset={_cancel_offset!r}, "
            f"content_formats={_content_formats!r}, "
            f"pricing_relationships={_pricing_relationships!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _name=(
            self.name
            if hasattr(self, "name")
            else None
        )
        _schedule_type=(
            self.schedule_type
            if hasattr(self, "schedule_type")
            else None
        )
        _cancel_offset=(
            self.cancel_offset
            if hasattr(self, "cancel_offset")
            else None
        )
        _content_formats=(
            self.content_formats
            if hasattr(self, "content_formats")
            else None
        )
        _pricing_relationships=(
            self.pricing_relationships
            if hasattr(self, "pricing_relationships")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!s}, "
            f"name={_name!s}, "
            f"schedule_type={_schedule_type!s}, "
            f"cancel_offset={_cancel_offset!s}, "
            f"content_formats={_content_formats!s}, "
            f"pricing_relationships={_pricing_relationships!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.sub_category import (
    SubCategory,
)


class Category(object):
    """Implementation of the 'Category' model.

    Attributes:
        id (int): The category Id used for api calls.
        category_name (str): Category Name
        description (str): Category Description
        service (bool): Category service
        active (bool): Check if Category is active.
        is_primary (bool): Check if Category is of primary type.
        is_secondary (bool): Check if Category is of secondary type.
        created_date_time_utc (datetime): Category Created DateTime UTC
        modified_date_time_utc (datetime): Category Modified DateTime UTC
        sub_categories (List[SubCategory]): Contains the SubCategory objects, each of
            which describes the subcategories for a category.
        total_count (int): Get total number of rows

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": "Id",
        "category_name": "CategoryName",
        "description": "Description",
        "service": "Service",
        "active": "Active",
        "is_primary": "IsPrimary",
        "is_secondary": "IsSecondary",
        "created_date_time_utc": "CreatedDateTimeUTC",
        "modified_date_time_utc": "ModifiedDateTimeUTC",
        "sub_categories": "SubCategories",
        "total_count": "TotalCount",
    }

    _optionals = [
        "id",
        "category_name",
        "description",
        "service",
        "active",
        "is_primary",
        "is_secondary",
        "created_date_time_utc",
        "modified_date_time_utc",
        "sub_categories",
        "total_count",
    ]

    def __init__(
        self,
        id=APIHelper.SKIP,
        category_name=APIHelper.SKIP,
        description=APIHelper.SKIP,
        service=APIHelper.SKIP,
        active=APIHelper.SKIP,
        is_primary=APIHelper.SKIP,
        is_secondary=APIHelper.SKIP,
        created_date_time_utc=APIHelper.SKIP,
        modified_date_time_utc=APIHelper.SKIP,
        sub_categories=APIHelper.SKIP,
        total_count=APIHelper.SKIP):
        """Initialize a Category instance."""
        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id
        if category_name is not APIHelper.SKIP:
            self.category_name = category_name
        if description is not APIHelper.SKIP:
            self.description = description
        if service is not APIHelper.SKIP:
            self.service = service
        if active is not APIHelper.SKIP:
            self.active = active
        if is_primary is not APIHelper.SKIP:
            self.is_primary = is_primary
        if is_secondary is not APIHelper.SKIP:
            self.is_secondary = is_secondary
        if created_date_time_utc is not APIHelper.SKIP:
            self.created_date_time_utc =\
                 APIHelper.apply_datetime_converter(
                created_date_time_utc, APIHelper.RFC3339DateTime)\
                 if created_date_time_utc else None
        if modified_date_time_utc is not APIHelper.SKIP:
            self.modified_date_time_utc =\
                 APIHelper.apply_datetime_converter(
                modified_date_time_utc, APIHelper.RFC3339DateTime)\
                 if modified_date_time_utc else None
        if sub_categories is not APIHelper.SKIP:
            self.sub_categories = sub_categories
        if total_count is not APIHelper.SKIP:
            self.total_count = total_count

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        category_name =\
            dictionary.get("CategoryName")\
            if dictionary.get("CategoryName")\
                else APIHelper.SKIP
        description =\
            dictionary.get("Description")\
            if dictionary.get("Description")\
                else APIHelper.SKIP
        service =\
            dictionary.get("Service")\
            if "Service" in dictionary.keys()\
                else APIHelper.SKIP
        active =\
            dictionary.get("Active")\
            if "Active" in dictionary.keys()\
                else APIHelper.SKIP
        is_primary =\
            dictionary.get("IsPrimary")\
            if "IsPrimary" in dictionary.keys()\
                else APIHelper.SKIP
        is_secondary =\
            dictionary.get("IsSecondary")\
            if "IsSecondary" in dictionary.keys()\
                else APIHelper.SKIP
        created_date_time_utc = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("CreatedDateTimeUTC")).datetime\
            if dictionary.get("CreatedDateTimeUTC") else APIHelper.SKIP
        modified_date_time_utc = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("ModifiedDateTimeUTC")).datetime\
            if dictionary.get("ModifiedDateTimeUTC") else APIHelper.SKIP
        sub_categories = None
        if dictionary.get("SubCategories") is not None:
            sub_categories = [
                SubCategory.from_dictionary(x)
                    for x in dictionary.get("SubCategories")
            ]
        else:
            sub_categories = APIHelper.SKIP
        total_count =\
            dictionary.get("TotalCount")\
            if dictionary.get("TotalCount")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(id,
                   category_name,
                   description,
                   service,
                   active,
                   is_primary,
                   is_secondary,
                   created_date_time_utc,
                   modified_date_time_utc,
                   sub_categories,
                   total_count)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _category_name=(
            self.category_name
            if hasattr(self, "category_name")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _service=(
            self.service
            if hasattr(self, "service")
            else None
        )
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        _is_primary=(
            self.is_primary
            if hasattr(self, "is_primary")
            else None
        )
        _is_secondary=(
            self.is_secondary
            if hasattr(self, "is_secondary")
            else None
        )
        _created_date_time_utc=(
            self.created_date_time_utc
            if hasattr(self, "created_date_time_utc")
            else None
        )
        _modified_date_time_utc=(
            self.modified_date_time_utc
            if hasattr(self, "modified_date_time_utc")
            else None
        )
        _sub_categories=(
            self.sub_categories
            if hasattr(self, "sub_categories")
            else None
        )
        _total_count=(
            self.total_count
            if hasattr(self, "total_count")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!r}, "
            f"category_name={_category_name!r}, "
            f"description={_description!r}, "
            f"service={_service!r}, "
            f"active={_active!r}, "
            f"is_primary={_is_primary!r}, "
            f"is_secondary={_is_secondary!r}, "
            f"created_date_time_utc={_created_date_time_utc!r}, "
            f"modified_date_time_utc={_modified_date_time_utc!r}, "
            f"sub_categories={_sub_categories!r}, "
            f"total_count={_total_count!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _category_name=(
            self.category_name
            if hasattr(self, "category_name")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _service=(
            self.service
            if hasattr(self, "service")
            else None
        )
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        _is_primary=(
            self.is_primary
            if hasattr(self, "is_primary")
            else None
        )
        _is_secondary=(
            self.is_secondary
            if hasattr(self, "is_secondary")
            else None
        )
        _created_date_time_utc=(
            self.created_date_time_utc
            if hasattr(self, "created_date_time_utc")
            else None
        )
        _modified_date_time_utc=(
            self.modified_date_time_utc
            if hasattr(self, "modified_date_time_utc")
            else None
        )
        _sub_categories=(
            self.sub_categories
            if hasattr(self, "sub_categories")
            else None
        )
        _total_count=(
            self.total_count
            if hasattr(self, "total_count")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!s}, "
            f"category_name={_category_name!s}, "
            f"description={_description!s}, "
            f"service={_service!s}, "
            f"active={_active!s}, "
            f"is_primary={_is_primary!s}, "
            f"is_secondary={_is_secondary!s}, "
            f"created_date_time_utc={_created_date_time_utc!s}, "
            f"modified_date_time_utc={_modified_date_time_utc!s}, "
            f"sub_categories={_sub_categories!s}, "
            f"total_count={_total_count!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.program_membership import (
    ProgramMembership,
)


class Membership(object):
    """Implementation of the 'Membership' model.

    Attributes:
        membership_id (int): The membership id.
        membership_name (str): The membership name.
        priority (int): The priority/sort order.
        member_retail_discount (float): The membership discount for retail as a
            percentage.
        member_service_discount (float): The membership discount for services as a
            percentage.
        allow_clients_to_schedule_unpaid (bool): Allow clients in this membership to
            schedule unpaid.
        online_booking_restricted_to_members_only (List[ProgramMembership]): List of
            programs that are restricted to clients in this membership only.
        day_of_month_scheduling_opens_for_next_month (int): Day of month scheduling
            opens for next month.  Unrestricted is a null value.
        restrict_self_sign_in_to_members_only (bool): Restrict self sign in to
            members only.
        allow_members_to_book_appointments_without_paying (bool): Allow members to
            book appointments without paying.
        allow_members_to_purchase_non_members_services (bool): Allow members to
            purchase non-members services.
        allow_members_to_purchase_non_members_products (bool): Allow members to
            purchase non-members products.
        is_active (bool): Indicates if the membership is active.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "membership_id": "MembershipId",
        "membership_name": "MembershipName",
        "priority": "Priority",
        "member_retail_discount": "MemberRetailDiscount",
        "member_service_discount": "MemberServiceDiscount",
        "allow_clients_to_schedule_unpaid": "AllowClientsToScheduleUnpaid",
        "online_booking_restricted_to_members_only":
            "OnlineBookingRestrictedToMembersOnly",
        "day_of_month_scheduling_opens_for_next_month":
            "DayOfMonthSchedulingOpensForNextMonth",
        "restrict_self_sign_in_to_members_only": "RestrictSelfSignInToMembersOnly",
        "allow_members_to_book_appointments_without_paying":
            "AllowMembersToBookAppointmentsWithoutPaying",
        "allow_members_to_purchase_non_members_services":
            "AllowMembersToPurchaseNonMembersServices",
        "allow_members_to_purchase_non_members_products":
            "AllowMembersToPurchaseNonMembersProducts",
        "is_active": "IsActive",
    }

    _optionals = [
        "membership_id",
        "membership_name",
        "priority",
        "member_retail_discount",
        "member_service_discount",
        "allow_clients_to_schedule_unpaid",
        "online_booking_restricted_to_members_only",
        "day_of_month_scheduling_opens_for_next_month",
        "restrict_self_sign_in_to_members_only",
        "allow_members_to_book_appointments_without_paying",
        "allow_members_to_purchase_non_members_services",
        "allow_members_to_purchase_non_members_products",
        "is_active",
    ]

    def __init__(
        self,
        membership_id=APIHelper.SKIP,
        membership_name=APIHelper.SKIP,
        priority=APIHelper.SKIP,
        member_retail_discount=APIHelper.SKIP,
        member_service_discount=APIHelper.SKIP,
        allow_clients_to_schedule_unpaid=APIHelper.SKIP,
        online_booking_restricted_to_members_only=APIHelper.SKIP,
        day_of_month_scheduling_opens_for_next_month=APIHelper.SKIP,
        restrict_self_sign_in_to_members_only=APIHelper.SKIP,
        allow_members_to_book_appointments_without_paying=APIHelper.SKIP,
        allow_members_to_purchase_non_members_services=APIHelper.SKIP,
        allow_members_to_purchase_non_members_products=APIHelper.SKIP,
        is_active=APIHelper.SKIP):
        """Initialize a Membership instance."""
        # Initialize members of the class
        if membership_id is not APIHelper.SKIP:
            self.membership_id = membership_id
        if membership_name is not APIHelper.SKIP:
            self.membership_name = membership_name
        if priority is not APIHelper.SKIP:
            self.priority = priority
        if member_retail_discount is not APIHelper.SKIP:
            self.member_retail_discount = member_retail_discount
        if member_service_discount is not APIHelper.SKIP:
            self.member_service_discount = member_service_discount
        if allow_clients_to_schedule_unpaid is not APIHelper.SKIP:
            self.allow_clients_to_schedule_unpaid = allow_clients_to_schedule_unpaid
        if online_booking_restricted_to_members_only is not APIHelper.SKIP:
            self.online_booking_restricted_to_members_only =\
                 online_booking_restricted_to_members_only
        if day_of_month_scheduling_opens_for_next_month is not APIHelper.SKIP:
            self.day_of_month_scheduling_opens_for_next_month =\
                 day_of_month_scheduling_opens_for_next_month
        if restrict_self_sign_in_to_members_only is not APIHelper.SKIP:
            self.restrict_self_sign_in_to_members_only =\
                 restrict_self_sign_in_to_members_only
        if allow_members_to_book_appointments_without_paying is not APIHelper.SKIP:
            self.allow_members_to_book_appointments_without_paying =\
                 allow_members_to_book_appointments_without_paying
        if allow_members_to_purchase_non_members_services is not APIHelper.SKIP:
            self.allow_members_to_purchase_non_members_services =\
                 allow_members_to_purchase_non_members_services
        if allow_members_to_purchase_non_members_products is not APIHelper.SKIP:
            self.allow_members_to_purchase_non_members_products =\
                 allow_members_to_purchase_non_members_products
        if is_active is not APIHelper.SKIP:
            self.is_active = is_active

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        membership_id =\
            dictionary.get("MembershipId")\
            if dictionary.get("MembershipId")\
                else APIHelper.SKIP
        membership_name =\
            dictionary.get("MembershipName")\
            if dictionary.get("MembershipName")\
                else APIHelper.SKIP
        priority =\
            dictionary.get("Priority")\
            if dictionary.get("Priority")\
                else APIHelper.SKIP
        member_retail_discount =\
            dictionary.get("MemberRetailDiscount")\
            if dictionary.get("MemberRetailDiscount")\
                else APIHelper.SKIP
        member_service_discount =\
            dictionary.get("MemberServiceDiscount")\
            if dictionary.get("MemberServiceDiscount")\
                else APIHelper.SKIP
        allow_clients_to_schedule_unpaid =\
            dictionary.get("AllowClientsToScheduleUnpaid")\
            if "AllowClientsToScheduleUnpaid" in dictionary.keys()\
                else APIHelper.SKIP
        online_booking_restricted_to_members_only = None
        if dictionary.get("OnlineBookingRestrictedToMembersOnly") is not None:
            online_booking_restricted_to_members_only = [
                ProgramMembership.from_dictionary(x)
                    for x in dictionary.get("OnlineBookingRestrictedToMembersOnly")
            ]
        else:
            online_booking_restricted_to_members_only = APIHelper.SKIP
        day_of_month_scheduling_opens_for_next_month =\
            dictionary.get("DayOfMonthSchedulingOpensForNextMonth")\
            if dictionary.get("DayOfMonthSchedulingOpensForNextMonth")\
                else APIHelper.SKIP
        restrict_self_sign_in_to_members_only =\
            dictionary.get("RestrictSelfSignInToMembersOnly")\
            if "RestrictSelfSignInToMembersOnly" in dictionary.keys()\
                else APIHelper.SKIP
        allow_members_to_book_appointments_without_paying =\
            dictionary.get("AllowMembersToBookAppointmentsWithoutPaying")\
            if "AllowMembersToBookAppointmentsWithoutPaying" in dictionary.keys()\
                else APIHelper.SKIP
        allow_members_to_purchase_non_members_services =\
            dictionary.get("AllowMembersToPurchaseNonMembersServices")\
            if "AllowMembersToPurchaseNonMembersServices" in dictionary.keys()\
                else APIHelper.SKIP
        allow_members_to_purchase_non_members_products =\
            dictionary.get("AllowMembersToPurchaseNonMembersProducts")\
            if "AllowMembersToPurchaseNonMembersProducts" in dictionary.keys()\
                else APIHelper.SKIP
        is_active =\
            dictionary.get("IsActive")\
            if "IsActive" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(membership_id,
                   membership_name,
                   priority,
                   member_retail_discount,
                   member_service_discount,
                   allow_clients_to_schedule_unpaid,
                   online_booking_restricted_to_members_only,
                   day_of_month_scheduling_opens_for_next_month,
                   restrict_self_sign_in_to_members_only,
                   allow_members_to_book_appointments_without_paying,
                   allow_members_to_purchase_non_members_services,
                   allow_members_to_purchase_non_members_products,
                   is_active)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _membership_id=(
            self.membership_id
            if hasattr(self, "membership_id")
            else None
        )
        _membership_name=(
            self.membership_name
            if hasattr(self, "membership_name")
            else None
        )
        _priority=(
            self.priority
            if hasattr(self, "priority")
            else None
        )
        _member_retail_discount=(
            self.member_retail_discount
            if hasattr(self, "member_retail_discount")
            else None
        )
        _member_service_discount=(
            self.member_service_discount
            if hasattr(self, "member_service_discount")
            else None
        )
        _allow_clients_to_schedule_unpaid=(
            self.allow_clients_to_schedule_unpaid
            if hasattr(self, "allow_clients_to_schedule_unpaid")
            else None
        )
        _online_booking_restricted_to_members_only=(
            self.online_booking_restricted_to_members_only
            if hasattr(self, "online_booking_restricted_to_members_only")
            else None
        )
        _day_of_month_scheduling_opens_for_next_month=(
            self.day_of_month_scheduling_opens_for_next_month
            if hasattr(self, "day_of_month_scheduling_opens_for_next_month")
            else None
        )
        _restrict_self_sign_in_to_members_only=(
            self.restrict_self_sign_in_to_members_only
            if hasattr(self, "restrict_self_sign_in_to_members_only")
            else None
        )
        _allow_members_to_book_appointments_without_paying=(
            self.allow_members_to_book_appointments_without_paying
            if hasattr(self, "allow_members_to_book_appointments_without_paying")
            else None
        )
        _allow_members_to_purchase_non_members_services=(
            self.allow_members_to_purchase_non_members_services
            if hasattr(self, "allow_members_to_purchase_non_members_services")
            else None
        )
        _allow_members_to_purchase_non_members_products=(
            self.allow_members_to_purchase_non_members_products
            if hasattr(self, "allow_members_to_purchase_non_members_products")
            else None
        )
        _is_active=(
            self.is_active
            if hasattr(self, "is_active")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"membership_id={_membership_id!r}, "
            f"membership_name={_membership_name!r}, "
            f"priority={_priority!r}, "
            f"member_retail_discount={_member_retail_discount!r}, "
            f"member_service_discount={_member_service_discount!r}, "
            f"allow_clients_to_schedule_unpaid={_allow_clients_to_schedule_unpaid!r}, "
            f"online_booking_restricted_to_members_only={_online_booking_restricted_to_members_only!r}, "
            f"day_of_month_scheduling_opens_for_next_month={_day_of_month_scheduling_opens_for_next_month!r}, "
            f"restrict_self_sign_in_to_members_only={_restrict_self_sign_in_to_members_only!r}, "
            f"allow_members_to_book_appointments_without_paying={_allow_members_to_book_appointments_without_paying!r}, "
            f"allow_members_to_purchase_non_members_services={_allow_members_to_purchase_non_members_services!r}, "
            f"allow_members_to_purchase_non_members_products={_allow_members_to_purchase_non_members_products!r}, "
            f"is_active={_is_active!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _membership_id=(
            self.membership_id
            if hasattr(self, "membership_id")
            else None
        )
        _membership_name=(
            self.membership_name
            if hasattr(self, "membership_name")
            else None
        )
        _priority=(
            self.priority
            if hasattr(self, "priority")
            else None
        )
        _member_retail_discount=(
            self.member_retail_discount
            if hasattr(self, "member_retail_discount")
            else None
        )
        _member_service_discount=(
            self.member_service_discount
            if hasattr(self, "member_service_discount")
            else None
        )
        _allow_clients_to_schedule_unpaid=(
            self.allow_clients_to_schedule_unpaid
            if hasattr(self, "allow_clients_to_schedule_unpaid")
            else None
        )
        _online_booking_restricted_to_members_only=(
            self.online_booking_restricted_to_members_only
            if hasattr(self, "online_booking_restricted_to_members_only")
            else None
        )
        _day_of_month_scheduling_opens_for_next_month=(
            self.day_of_month_scheduling_opens_for_next_month
            if hasattr(self, "day_of_month_scheduling_opens_for_next_month")
            else None
        )
        _restrict_self_sign_in_to_members_only=(
            self.restrict_self_sign_in_to_members_only
            if hasattr(self, "restrict_self_sign_in_to_members_only")
            else None
        )
        _allow_members_to_book_appointments_without_paying=(
            self.allow_members_to_book_appointments_without_paying
            if hasattr(self, "allow_members_to_book_appointments_without_paying")
            else None
        )
        _allow_members_to_purchase_non_members_services=(
            self.allow_members_to_purchase_non_members_services
            if hasattr(self, "allow_members_to_purchase_non_members_services")
            else None
        )
        _allow_members_to_purchase_non_members_products=(
            self.allow_members_to_purchase_non_members_products
            if hasattr(self, "allow_members_to_purchase_non_members_products")
            else None
        )
        _is_active=(
            self.is_active
            if hasattr(self, "is_active")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"membership_id={_membership_id!s}, "
            f"membership_name={_membership_name!s}, "
            f"priority={_priority!s}, "
            f"member_retail_discount={_member_retail_discount!s}, "
            f"member_service_discount={_member_service_discount!s}, "
            f"allow_clients_to_schedule_unpaid={_allow_clients_to_schedule_unpaid!s}, "
            f"online_booking_restricted_to_members_only={_online_booking_restricted_to_members_only!s}, "
            f"day_of_month_scheduling_opens_for_next_month={_day_of_month_scheduling_opens_for_next_month!s}, "
            f"restrict_self_sign_in_to_members_only={_restrict_self_sign_in_to_members_only!s}, "
            f"allow_members_to_book_appointments_without_paying={_allow_members_to_book_appointments_without_paying!s}, "
            f"allow_members_to_purchase_non_members_services={_allow_members_to_purchase_non_members_services!s}, "
            f"allow_members_to_purchase_non_members_products={_allow_members_to_purchase_non_members_products!s}, "
            f"is_active={_is_active!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.location_1 import (
    Location1,
)
from mindbodypublicapi.models.program_1 import (
    Program1,
)
from mindbodypublicapi.models.resource_availability_1 import (
    ResourceAvailability1,
)
from mindbodypublicapi.models.session_type_1 import (
    SessionType1,
)
from mindbodypublicapi.models.staff_1 import (
    Staff1,
)


class Availability1(object):
    """Implementation of the 'Availability1' model.

    The availability of a specific staff

    Attributes:
        id (int): Id of the availability
        staff (Staff1): The model property of type Staff1.
        session_type (SessionType1): The model property of type SessionType1.
        programs (List[Program1]): Availabilities program list.
        start_date_time (datetime): Availabilities start date and time.
        end_date_time (datetime): Availabilities end date and time.
        bookable_end_date_time (datetime): Availabilities bookable end date and time.
        location (Location1): The model property of type Location1.
        prep_time (int): Appointment prep time
        finish_time (int): Appointment finish time
        is_masked (bool): The model property of type bool.
        show_public (bool): The model property of type bool.
        resource_availabilities (List[ResourceAvailability1]): List of resource
            availabilities that can be booked with this session type.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": "Id",
        "staff": "Staff",
        "session_type": "SessionType",
        "programs": "Programs",
        "start_date_time": "StartDateTime",
        "end_date_time": "EndDateTime",
        "bookable_end_date_time": "BookableEndDateTime",
        "location": "Location",
        "prep_time": "PrepTime",
        "finish_time": "FinishTime",
        "is_masked": "IsMasked",
        "show_public": "ShowPublic",
        "resource_availabilities": "ResourceAvailabilities",
    }

    _optionals = [
        "id",
        "staff",
        "session_type",
        "programs",
        "start_date_time",
        "end_date_time",
        "bookable_end_date_time",
        "location",
        "prep_time",
        "finish_time",
        "is_masked",
        "show_public",
        "resource_availabilities",
    ]

    def __init__(
        self,
        id=APIHelper.SKIP,
        staff=APIHelper.SKIP,
        session_type=APIHelper.SKIP,
        programs=APIHelper.SKIP,
        start_date_time=APIHelper.SKIP,
        end_date_time=APIHelper.SKIP,
        bookable_end_date_time=APIHelper.SKIP,
        location=APIHelper.SKIP,
        prep_time=APIHelper.SKIP,
        finish_time=APIHelper.SKIP,
        is_masked=APIHelper.SKIP,
        show_public=APIHelper.SKIP,
        resource_availabilities=APIHelper.SKIP):
        """Initialize a Availability1 instance."""
        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id
        if staff is not APIHelper.SKIP:
            self.staff = staff
        if session_type is not APIHelper.SKIP:
            self.session_type = session_type
        if programs is not APIHelper.SKIP:
            self.programs = programs
        if start_date_time is not APIHelper.SKIP:
            self.start_date_time =\
                 APIHelper.apply_datetime_converter(
                start_date_time, APIHelper.RFC3339DateTime)\
                 if start_date_time else None
        if end_date_time is not APIHelper.SKIP:
            self.end_date_time =\
                 APIHelper.apply_datetime_converter(
                end_date_time, APIHelper.RFC3339DateTime)\
                 if end_date_time else None
        if bookable_end_date_time is not APIHelper.SKIP:
            self.bookable_end_date_time =\
                 APIHelper.apply_datetime_converter(
                bookable_end_date_time, APIHelper.RFC3339DateTime)\
                 if bookable_end_date_time else None
        if location is not APIHelper.SKIP:
            self.location = location
        if prep_time is not APIHelper.SKIP:
            self.prep_time = prep_time
        if finish_time is not APIHelper.SKIP:
            self.finish_time = finish_time
        if is_masked is not APIHelper.SKIP:
            self.is_masked = is_masked
        if show_public is not APIHelper.SKIP:
            self.show_public = show_public
        if resource_availabilities is not APIHelper.SKIP:
            self.resource_availabilities = resource_availabilities

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        staff =\
            Staff1.from_dictionary(
                dictionary.get("Staff"))\
                if "Staff" in dictionary.keys()\
                else APIHelper.SKIP
        session_type =\
            SessionType1.from_dictionary(
                dictionary.get("SessionType"))\
                if "SessionType" in dictionary.keys()\
                else APIHelper.SKIP
        programs = None
        if dictionary.get("Programs") is not None:
            programs = [
                Program1.from_dictionary(x)
                    for x in dictionary.get("Programs")
            ]
        else:
            programs = APIHelper.SKIP
        start_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDateTime")).datetime\
            if dictionary.get("StartDateTime") else APIHelper.SKIP
        end_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDateTime")).datetime\
            if dictionary.get("EndDateTime") else APIHelper.SKIP
        bookable_end_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("BookableEndDateTime")).datetime\
            if dictionary.get("BookableEndDateTime") else APIHelper.SKIP
        location =\
            Location1.from_dictionary(
                dictionary.get("Location"))\
                if "Location" in dictionary.keys()\
                else APIHelper.SKIP
        prep_time =\
            dictionary.get("PrepTime")\
            if dictionary.get("PrepTime")\
                else APIHelper.SKIP
        finish_time =\
            dictionary.get("FinishTime")\
            if dictionary.get("FinishTime")\
                else APIHelper.SKIP
        is_masked =\
            dictionary.get("IsMasked")\
            if "IsMasked" in dictionary.keys()\
                else APIHelper.SKIP
        show_public =\
            dictionary.get("ShowPublic")\
            if "ShowPublic" in dictionary.keys()\
                else APIHelper.SKIP
        resource_availabilities = None
        if dictionary.get("ResourceAvailabilities") is not None:
            resource_availabilities = [
                ResourceAvailability1.from_dictionary(x)
                    for x in dictionary.get("ResourceAvailabilities")
            ]
        else:
            resource_availabilities = APIHelper.SKIP

        # Return an object of this model
        return cls(id,
                   staff,
                   session_type,
                   programs,
                   start_date_time,
                   end_date_time,
                   bookable_end_date_time,
                   location,
                   prep_time,
                   finish_time,
                   is_masked,
                   show_public,
                   resource_availabilities)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _staff=(
            self.staff
            if hasattr(self, "staff")
            else None
        )
        _session_type=(
            self.session_type
            if hasattr(self, "session_type")
            else None
        )
        _programs=(
            self.programs
            if hasattr(self, "programs")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _bookable_end_date_time=(
            self.bookable_end_date_time
            if hasattr(self, "bookable_end_date_time")
            else None
        )
        _location=(
            self.location
            if hasattr(self, "location")
            else None
        )
        _prep_time=(
            self.prep_time
            if hasattr(self, "prep_time")
            else None
        )
        _finish_time=(
            self.finish_time
            if hasattr(self, "finish_time")
            else None
        )
        _is_masked=(
            self.is_masked
            if hasattr(self, "is_masked")
            else None
        )
        _show_public=(
            self.show_public
            if hasattr(self, "show_public")
            else None
        )
        _resource_availabilities=(
            self.resource_availabilities
            if hasattr(self, "resource_availabilities")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!r}, "
            f"staff={_staff!r}, "
            f"session_type={_session_type!r}, "
            f"programs={_programs!r}, "
            f"start_date_time={_start_date_time!r}, "
            f"end_date_time={_end_date_time!r}, "
            f"bookable_end_date_time={_bookable_end_date_time!r}, "
            f"location={_location!r}, "
            f"prep_time={_prep_time!r}, "
            f"finish_time={_finish_time!r}, "
            f"is_masked={_is_masked!r}, "
            f"show_public={_show_public!r}, "
            f"resource_availabilities={_resource_availabilities!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _staff=(
            self.staff
            if hasattr(self, "staff")
            else None
        )
        _session_type=(
            self.session_type
            if hasattr(self, "session_type")
            else None
        )
        _programs=(
            self.programs
            if hasattr(self, "programs")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _bookable_end_date_time=(
            self.bookable_end_date_time
            if hasattr(self, "bookable_end_date_time")
            else None
        )
        _location=(
            self.location
            if hasattr(self, "location")
            else None
        )
        _prep_time=(
            self.prep_time
            if hasattr(self, "prep_time")
            else None
        )
        _finish_time=(
            self.finish_time
            if hasattr(self, "finish_time")
            else None
        )
        _is_masked=(
            self.is_masked
            if hasattr(self, "is_masked")
            else None
        )
        _show_public=(
            self.show_public
            if hasattr(self, "show_public")
            else None
        )
        _resource_availabilities=(
            self.resource_availabilities
            if hasattr(self, "resource_availabilities")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!s}, "
            f"staff={_staff!s}, "
            f"session_type={_session_type!s}, "
            f"programs={_programs!s}, "
            f"start_date_time={_start_date_time!s}, "
            f"end_date_time={_end_date_time!s}, "
            f"bookable_end_date_time={_bookable_end_date_time!s}, "
            f"location={_location!s}, "
            f"prep_time={_prep_time!s}, "
            f"finish_time={_finish_time!s}, "
            f"is_masked={_is_masked!s}, "
            f"show_public={_show_public!s}, "
            f"resource_availabilities={_resource_availabilities!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class UpdateAppointmentRequest(object):
    """Implementation of the 'UpdateAppointmentRequest' model.

    Attributes:
        appointment_id (int): A unique ID for the appointment.
        end_date_time (datetime): The end date and time of the new appointment.   <br
            />Default: **StartDateTime**, offset by the staff member’s default
            appointment duration.
        execute (str): The action taken to add this appointment. Possible values are:
            confirm, unconfirm, arrive, unarrive, cancel, latecancel, complete.
        gender_preference (str): The client’s service provider gender preference.
        notes (str): Any general notes about this appointment.
        partner_external_id (str): Optional external key for api partners.
        provider_id (str): If a user has Complementary and Alternative Medicine
            features enabled, this parameter assigns a provider ID to the appointment.
        resource_ids (List[int]): A list of resource IDs to associate with the new
            appointment.
        send_email (bool): Whether to send client an email for cancellations. An
            email is sent only if the client has an email address and automatic
            emails have been set up.   <br />Default: **false**
        session_type_id (int): The session type associated with the new appointment.
        staff_id (int): The ID of the staff member who is adding the new appointment.
        start_date_time (datetime): The start date and time of the new appointment.
        apply_payment (bool): When `true`, appointment will be updated with a current
            applicable client service from the clients account.   <br />Default:
            **false**
        test (bool): When `true`, indicates that the method is to be validated, but
            no new appointment data is added.   <br />Default: **false**

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "appointment_id": "AppointmentId",
        "end_date_time": "EndDateTime",
        "execute": "Execute",
        "gender_preference": "GenderPreference",
        "notes": "Notes",
        "partner_external_id": "PartnerExternalId",
        "provider_id": "ProviderId",
        "resource_ids": "ResourceIds",
        "send_email": "SendEmail",
        "session_type_id": "SessionTypeId",
        "staff_id": "StaffId",
        "start_date_time": "StartDateTime",
        "apply_payment": "ApplyPayment",
        "test": "Test",
    }

    _optionals = [
        "end_date_time",
        "execute",
        "gender_preference",
        "notes",
        "partner_external_id",
        "provider_id",
        "resource_ids",
        "send_email",
        "session_type_id",
        "staff_id",
        "start_date_time",
        "apply_payment",
        "test",
    ]

    def __init__(
        self,
        appointment_id=None,
        end_date_time=APIHelper.SKIP,
        execute=APIHelper.SKIP,
        gender_preference=APIHelper.SKIP,
        notes=APIHelper.SKIP,
        partner_external_id=APIHelper.SKIP,
        provider_id=APIHelper.SKIP,
        resource_ids=APIHelper.SKIP,
        send_email=APIHelper.SKIP,
        session_type_id=APIHelper.SKIP,
        staff_id=APIHelper.SKIP,
        start_date_time=APIHelper.SKIP,
        apply_payment=APIHelper.SKIP,
        test=APIHelper.SKIP):
        """Initialize a UpdateAppointmentRequest instance."""
        # Initialize members of the class
        self.appointment_id = appointment_id
        if end_date_time is not APIHelper.SKIP:
            self.end_date_time =\
                 APIHelper.apply_datetime_converter(
                end_date_time, APIHelper.RFC3339DateTime)\
                 if end_date_time else None
        if execute is not APIHelper.SKIP:
            self.execute = execute
        if gender_preference is not APIHelper.SKIP:
            self.gender_preference = gender_preference
        if notes is not APIHelper.SKIP:
            self.notes = notes
        if partner_external_id is not APIHelper.SKIP:
            self.partner_external_id = partner_external_id
        if provider_id is not APIHelper.SKIP:
            self.provider_id = provider_id
        if resource_ids is not APIHelper.SKIP:
            self.resource_ids = resource_ids
        if send_email is not APIHelper.SKIP:
            self.send_email = send_email
        if session_type_id is not APIHelper.SKIP:
            self.session_type_id = session_type_id
        if staff_id is not APIHelper.SKIP:
            self.staff_id = staff_id
        if start_date_time is not APIHelper.SKIP:
            self.start_date_time =\
                 APIHelper.apply_datetime_converter(
                start_date_time, APIHelper.RFC3339DateTime)\
                 if start_date_time else None
        if apply_payment is not APIHelper.SKIP:
            self.apply_payment = apply_payment
        if test is not APIHelper.SKIP:
            self.test = test

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        appointment_id =\
            dictionary.get("AppointmentId")\
            if dictionary.get("AppointmentId")\
                else None
        end_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDateTime")).datetime\
            if dictionary.get("EndDateTime") else APIHelper.SKIP
        execute =\
            dictionary.get("Execute")\
            if dictionary.get("Execute")\
                else APIHelper.SKIP
        gender_preference =\
            dictionary.get("GenderPreference")\
            if dictionary.get("GenderPreference")\
                else APIHelper.SKIP
        notes =\
            dictionary.get("Notes")\
            if dictionary.get("Notes")\
                else APIHelper.SKIP
        partner_external_id =\
            dictionary.get("PartnerExternalId")\
            if dictionary.get("PartnerExternalId")\
                else APIHelper.SKIP
        provider_id =\
            dictionary.get("ProviderId")\
            if dictionary.get("ProviderId")\
                else APIHelper.SKIP
        resource_ids =\
            dictionary.get("ResourceIds")\
            if dictionary.get("ResourceIds")\
                else APIHelper.SKIP
        send_email =\
            dictionary.get("SendEmail")\
            if "SendEmail" in dictionary.keys()\
                else APIHelper.SKIP
        session_type_id =\
            dictionary.get("SessionTypeId")\
            if dictionary.get("SessionTypeId")\
                else APIHelper.SKIP
        staff_id =\
            dictionary.get("StaffId")\
            if dictionary.get("StaffId")\
                else APIHelper.SKIP
        start_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDateTime")).datetime\
            if dictionary.get("StartDateTime") else APIHelper.SKIP
        apply_payment =\
            dictionary.get("ApplyPayment")\
            if "ApplyPayment" in dictionary.keys()\
                else APIHelper.SKIP
        test =\
            dictionary.get("Test")\
            if "Test" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(appointment_id,
                   end_date_time,
                   execute,
                   gender_preference,
                   notes,
                   partner_external_id,
                   provider_id,
                   resource_ids,
                   send_email,
                   session_type_id,
                   staff_id,
                   start_date_time,
                   apply_payment,
                   test)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _appointment_id=self.appointment_id
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _execute=(
            self.execute
            if hasattr(self, "execute")
            else None
        )
        _gender_preference=(
            self.gender_preference
            if hasattr(self, "gender_preference")
            else None
        )
        _notes=(
            self.notes
            if hasattr(self, "notes")
            else None
        )
        _partner_external_id=(
            self.partner_external_id
            if hasattr(self, "partner_external_id")
            else None
        )
        _provider_id=(
            self.provider_id
            if hasattr(self, "provider_id")
            else None
        )
        _resource_ids=(
            self.resource_ids
            if hasattr(self, "resource_ids")
            else None
        )
        _send_email=(
            self.send_email
            if hasattr(self, "send_email")
            else None
        )
        _session_type_id=(
            self.session_type_id
            if hasattr(self, "session_type_id")
            else None
        )
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _apply_payment=(
            self.apply_payment
            if hasattr(self, "apply_payment")
            else None
        )
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"appointment_id={_appointment_id!r}, "
            f"end_date_time={_end_date_time!r}, "
            f"execute={_execute!r}, "
            f"gender_preference={_gender_preference!r}, "
            f"notes={_notes!r}, "
            f"partner_external_id={_partner_external_id!r}, "
            f"provider_id={_provider_id!r}, "
            f"resource_ids={_resource_ids!r}, "
            f"send_email={_send_email!r}, "
            f"session_type_id={_session_type_id!r}, "
            f"staff_id={_staff_id!r}, "
            f"start_date_time={_start_date_time!r}, "
            f"apply_payment={_apply_payment!r}, "
            f"test={_test!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _appointment_id=self.appointment_id
        _end_date_time=(
            self.end_date_time
            if hasattr(self, "end_date_time")
            else None
        )
        _execute=(
            self.execute
            if hasattr(self, "execute")
            else None
        )
        _gender_preference=(
            self.gender_preference
            if hasattr(self, "gender_preference")
            else None
        )
        _notes=(
            self.notes
            if hasattr(self, "notes")
            else None
        )
        _partner_external_id=(
            self.partner_external_id
            if hasattr(self, "partner_external_id")
            else None
        )
        _provider_id=(
            self.provider_id
            if hasattr(self, "provider_id")
            else None
        )
        _resource_ids=(
            self.resource_ids
            if hasattr(self, "resource_ids")
            else None
        )
        _send_email=(
            self.send_email
            if hasattr(self, "send_email")
            else None
        )
        _session_type_id=(
            self.session_type_id
            if hasattr(self, "session_type_id")
            else None
        )
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _start_date_time=(
            self.start_date_time
            if hasattr(self, "start_date_time")
            else None
        )
        _apply_payment=(
            self.apply_payment
            if hasattr(self, "apply_payment")
            else None
        )
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"appointment_id={_appointment_id!s}, "
            f"end_date_time={_end_date_time!s}, "
            f"execute={_execute!s}, "
            f"gender_preference={_gender_preference!s}, "
            f"notes={_notes!s}, "
            f"partner_external_id={_partner_external_id!s}, "
            f"provider_id={_provider_id!s}, "
            f"resource_ids={_resource_ids!s}, "
            f"send_email={_send_email!s}, "
            f"session_type_id={_session_type_id!s}, "
            f"staff_id={_staff_id!s}, "
            f"start_date_time={_start_date_time!s}, "
            f"apply_payment={_apply_payment!s}, "
            f"test={_test!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class ScheduledServiceEarningsEvent(object):
    """Implementation of the 'ScheduledServiceEarningsEvent' model.

    Attributes:
        staff_id (int): The ID of the staff member who taught the class.
        scheduled_service_id (int): The class' ID.
        scheduled_service_type (ScheduledServiceTypeEnum): The type of the scheduled
            service; i.e, a class, appointment, or enrollment.
        earnings (float): The total monetary amount the staff is to be paid for this
            class.
        date_time (datetime): The model property of type datetime.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "staff_id": "StaffId",
        "scheduled_service_id": "ScheduledServiceId",
        "scheduled_service_type": "ScheduledServiceType",
        "earnings": "Earnings",
        "date_time": "DateTime",
    }

    _optionals = [
        "staff_id",
        "scheduled_service_id",
        "scheduled_service_type",
        "earnings",
        "date_time",
    ]

    def __init__(
        self,
        staff_id=APIHelper.SKIP,
        scheduled_service_id=APIHelper.SKIP,
        scheduled_service_type=APIHelper.SKIP,
        earnings=APIHelper.SKIP,
        date_time=APIHelper.SKIP):
        """Initialize a ScheduledServiceEarningsEvent instance."""
        # Initialize members of the class
        if staff_id is not APIHelper.SKIP:
            self.staff_id = staff_id
        if scheduled_service_id is not APIHelper.SKIP:
            self.scheduled_service_id = scheduled_service_id
        if scheduled_service_type is not APIHelper.SKIP:
            self.scheduled_service_type = scheduled_service_type
        if earnings is not APIHelper.SKIP:
            self.earnings = earnings
        if date_time is not APIHelper.SKIP:
            self.date_time =\
                 APIHelper.apply_datetime_converter(
                date_time, APIHelper.RFC3339DateTime)\
                 if date_time else None

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        staff_id =\
            dictionary.get("StaffId")\
            if dictionary.get("StaffId")\
                else APIHelper.SKIP
        scheduled_service_id =\
            dictionary.get("ScheduledServiceId")\
            if dictionary.get("ScheduledServiceId")\
                else APIHelper.SKIP
        scheduled_service_type =\
            dictionary.get("ScheduledServiceType")\
            if dictionary.get("ScheduledServiceType")\
                else APIHelper.SKIP
        earnings =\
            dictionary.get("Earnings")\
            if dictionary.get("Earnings")\
                else APIHelper.SKIP
        date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("DateTime")).datetime\
            if dictionary.get("DateTime") else APIHelper.SKIP

        # Return an object of this model
        return cls(staff_id,
                   scheduled_service_id,
                   scheduled_service_type,
                   earnings,
                   date_time)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _scheduled_service_id=(
            self.scheduled_service_id
            if hasattr(self, "scheduled_service_id")
            else None
        )
        _scheduled_service_type=(
            self.scheduled_service_type
            if hasattr(self, "scheduled_service_type")
            else None
        )
        _earnings=(
            self.earnings
            if hasattr(self, "earnings")
            else None
        )
        _date_time=(
            self.date_time
            if hasattr(self, "date_time")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"staff_id={_staff_id!r}, "
            f"scheduled_service_id={_scheduled_service_id!r}, "
            f"scheduled_service_type={_scheduled_service_type!r}, "
            f"earnings={_earnings!r}, "
            f"date_time={_date_time!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _scheduled_service_id=(
            self.scheduled_service_id
            if hasattr(self, "scheduled_service_id")
            else None
        )
        _scheduled_service_type=(
            self.scheduled_service_type
            if hasattr(self, "scheduled_service_type")
            else None
        )
        _earnings=(
            self.earnings
            if hasattr(self, "earnings")
            else None
        )
        _date_time=(
            self.date_time
            if hasattr(self, "date_time")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"staff_id={_staff_id!s}, "
            f"scheduled_service_id={_scheduled_service_id!s}, "
            f"scheduled_service_type={_scheduled_service_type!s}, "
            f"earnings={_earnings!s}, "
            f"date_time={_date_time!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.commission_detail import (
    CommissionDetail,
)


class CommissionPayrollPurchaseEvent(object):
    """Implementation of the 'CommissionPayrollPurchaseEvent' model.

    Attributes:
        staff_id (int): The ID of the staff member who earned commissions.
        sale_date_time (datetime): The date and time when the sale occurred.
        sale_id (int): The sale’s ID.
        sale_type (str): The Sales type. When this is "Purchase" indicates that this
            sale paid commission to a staff. When this is "Return"
        product_id (int): The product ID of the item for which the staff earned
            commissions.
        earnings_details (List[CommissionDetail]): Contains information about which
            commissions the staff earned for this item.
        earnings (float): The total commissions earned by the staff for this item.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "staff_id": "StaffId",
        "sale_date_time": "SaleDateTime",
        "sale_id": "SaleId",
        "sale_type": "SaleType",
        "product_id": "ProductId",
        "earnings_details": "EarningsDetails",
        "earnings": "Earnings",
    }

    _optionals = [
        "staff_id",
        "sale_date_time",
        "sale_id",
        "sale_type",
        "product_id",
        "earnings_details",
        "earnings",
    ]

    def __init__(
        self,
        staff_id=APIHelper.SKIP,
        sale_date_time=APIHelper.SKIP,
        sale_id=APIHelper.SKIP,
        sale_type=APIHelper.SKIP,
        product_id=APIHelper.SKIP,
        earnings_details=APIHelper.SKIP,
        earnings=APIHelper.SKIP):
        """Initialize a CommissionPayrollPurchaseEvent instance."""
        # Initialize members of the class
        if staff_id is not APIHelper.SKIP:
            self.staff_id = staff_id
        if sale_date_time is not APIHelper.SKIP:
            self.sale_date_time =\
                 APIHelper.apply_datetime_converter(
                sale_date_time, APIHelper.RFC3339DateTime)\
                 if sale_date_time else None
        if sale_id is not APIHelper.SKIP:
            self.sale_id = sale_id
        if sale_type is not APIHelper.SKIP:
            self.sale_type = sale_type
        if product_id is not APIHelper.SKIP:
            self.product_id = product_id
        if earnings_details is not APIHelper.SKIP:
            self.earnings_details = earnings_details
        if earnings is not APIHelper.SKIP:
            self.earnings = earnings

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        staff_id =\
            dictionary.get("StaffId")\
            if dictionary.get("StaffId")\
                else APIHelper.SKIP
        sale_date_time = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("SaleDateTime")).datetime\
            if dictionary.get("SaleDateTime") else APIHelper.SKIP
        sale_id =\
            dictionary.get("SaleId")\
            if dictionary.get("SaleId")\
                else APIHelper.SKIP
        sale_type =\
            dictionary.get("SaleType")\
            if dictionary.get("SaleType")\
                else APIHelper.SKIP
        product_id =\
            dictionary.get("ProductId")\
            if dictionary.get("ProductId")\
                else APIHelper.SKIP
        earnings_details = None
        if dictionary.get("EarningsDetails") is not None:
            earnings_details = [
                CommissionDetail.from_dictionary(x)
                    for x in dictionary.get("EarningsDetails")
            ]
        else:
            earnings_details = APIHelper.SKIP
        earnings =\
            dictionary.get("Earnings")\
            if dictionary.get("Earnings")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(staff_id,
                   sale_date_time,
                   sale_id,
                   sale_type,
                   product_id,
                   earnings_details,
                   earnings)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _sale_date_time=(
            self.sale_date_time
            if hasattr(self, "sale_date_time")
            else None
        )
        _sale_id=(
            self.sale_id
            if hasattr(self, "sale_id")
            else None
        )
        _sale_type=(
            self.sale_type
            if hasattr(self, "sale_type")
            else None
        )
        _product_id=(
            self.product_id
            if hasattr(self, "product_id")
            else None
        )
        _earnings_details=(
            self.earnings_details
            if hasattr(self, "earnings_details")
            else None
        )
        _earnings=(
            self.earnings
            if hasattr(self, "earnings")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"staff_id={_staff_id!r}, "
            f"sale_date_time={_sale_date_time!r}, "
            f"sale_id={_sale_id!r}, "
            f"sale_type={_sale_type!r}, "
            f"product_id={_product_id!r}, "
            f"earnings_details={_earnings_details!r}, "
            f"earnings={_earnings!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _staff_id=(
            self.staff_id
            if hasattr(self, "staff_id")
            else None
        )
        _sale_date_time=(
            self.sale_date_time
            if hasattr(self, "sale_date_time")
            else None
        )
        _sale_id=(
            self.sale_id
            if hasattr(self, "sale_id")
            else None
        )
        _sale_type=(
            self.sale_type
            if hasattr(self, "sale_type")
            else None
        )
        _product_id=(
            self.product_id
            if hasattr(self, "product_id")
            else None
        )
        _earnings_details=(
            self.earnings_details
            if hasattr(self, "earnings_details")
            else None
        )
        _earnings=(
            self.earnings
            if hasattr(self, "earnings")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"staff_id={_staff_id!s}, "
            f"sale_date_time={_sale_date_time!s}, "
            f"sale_id={_sale_id!s}, "
            f"sale_type={_sale_type!s}, "
            f"product_id={_product_id!s}, "
            f"earnings_details={_earnings_details!s}, "
            f"earnings={_earnings!s}, "
            f")"
        )
